/************************************************************************
 *
 * sru21479.h
 *
 * (c) Copyright 2007-2010 Analog Devices, Inc.  All rights reserved.
 *
 ************************************************************************/

/* This include file contains a list of macro "defines" to enable the
** programmer to use symbolic names for ADSP-21479 SRU
** This is intended to simplify patching in the Signal Routing Unit (SRU)
** The SRU macro is as follows: SRU(OUT,IN)
*/

#ifndef __SRU21479_H_
#define __SRU21479_H_

#ifdef _MISRA_RULES
#pragma diag(push)
#pragma diag(suppress:misra_rule_19_4)
#pragma diag(suppress:misra_rule_19_7)
#pragma diag(suppress:misra_rule_19_10)
#pragma diag(suppress:misra_rule_19_12)
#pragma diag(suppress:misra_rule_19_13)
#endif /* _MISRA_RULES */

/*
** Uncomment the following definition for SRUDEBUG, or add SRUDEBUG to
** preprocessor definitions in project options or source file for the
** Assembler/Compiler to allow the SRU macro to check its inputs for
** validity. Without this check, it is possible to have an errorless/warningless
** build that did not have valid signals routed according to the groupings
** in the 2146x Hardware Reference, caused by invalid user input.
** Enabling error checking increases the memory used by the macro. Once the
** routings are verified, it is no longer necessary to enable the error
** checking mechanism.
*/
/* #define SRUDEBUG */

/* We need the following header file for the SRU register address definitions */
# include <def21479.h>

#if !defined(SRUDEBUG)
/*
** Macro: SRU
** Reads, modifies and writes back a particular SRU register to change a single
** SRU assignment (i.e. selects an input to an output).
*/
# ifdef _LANGUAGE_C
#  define SRU(out,in)                        \
     do {                                    \
       *(volatile unsigned int *) in##_REG = \
         (sru_field(out,in) |                \
         (* (volatile unsigned int *) in##_REG & sru_mask(out,in))); \
     } while (0)
# else
#  define SRU(out,in)        \
     r0=dm(in##_REG);        \
     r1=sru_mask(out,in);    \
     r0=r0 and r1;           \
     r1=sru_field(out,in);   \
     r0=r0 or r1;            \
     dm(in##_REG)=r0;
# endif
#else /* SRUDEBUG */
/*
** Macro: SRU with error checking
** Checks for incompatible input and output selections. Valid routings will
** read, modify and write back a particular SRU register to change a single
** SRU assignment (i.e. selects an input to an output).
** Invalid routings will hang infinitely with the PC pointing to the offending
** routing code.
** The compiler will generate warnings for unreachable code when the routing
** is invalid.
*/
# ifdef _LANGUAGE_C
#  define SRU(out,in)                         \
     do {                                     \
       SRU_ERROR_CHECK(out,in)                \
       * (volatile unsigned int *) in##_REG = \
           (sru_field(out,in) |           \
            (* (volatile unsigned int *) in##_REG & sru_mask(out,in))); \
     } while (0)
#  define SRU_ERROR_CHECK(out,in) if(!sru_check(out,in)) while(1);
# else
#  define SRU(out,in)        \
     SRU_ERROR_CHECK(out,in) \
     r0=dm(in##_REG);        \
     r1=sru_mask(out,in);    \
     r0=r0 and r1;           \
     r1=sru_field(out,in);   \
     r0=r0 or r1;            \
     dm(in##_REG)=r0;
#  define SRU_ERROR_CHECK(out,in) \
     r1 = sru_check(out,in);      \
     r1 = pass r1;                \
     if ne jump(pc,LEGAL_ROUTING?); \
     ILLEGAL_ROUTING_DETECTED?:   \
     jump(pc,0);                  \
     LEGAL_ROUTING?:
#endif
#endif /* SRUDEBUG */

#define SRU2(out,in)   SRU(out,in)


/*
**   Macro: sru_field
**   Creates the bit field for a given input and output signal.
*/
#define sru_field(out,in) \
    (((in##_GROUP & GROUP_A) >> LOG_GROUP_A) * A_##out \
    |((in##_GROUP & GROUP_B) >> LOG_GROUP_B) * B_##out \
    |((in##_GROUP & GROUP_C) >> LOG_GROUP_C) * C_##out \
    |((in##_GROUP & GROUP_D) >> LOG_GROUP_D) * D_##out \
    |((in##_GROUP & GROUP_E) >> LOG_GROUP_E) * E_##out \
    |((in##_GROUP & GROUP_F) >> LOG_GROUP_F) * F_##out \
    |((in##_GROUP & GROUP_G) >> LOG_GROUP_G) * G_##out \
    |((in##_GROUP & GROUP_H) >> LOG_GROUP_H) * H_##out \
    |((in##_GROUP & GROUP_I) >> LOG_GROUP_I) * I_##out \
    |((in##_GROUP & GROUP_A2)>> LOG_GROUP_A2)* A2_##out \
    |((in##_GROUP & GROUP_B2)>> LOG_GROUP_B2)* B2_##out \
    |((in##_GROUP & GROUP_C2)>> LOG_GROUP_C2)* C2_##out ) << in##_SHIFT

/*
**   Macro: sru_mask
**   Creates a mask which can be used for clearing the bitfield belonging
**   to the given input and output signal.
*/
#define sru_mask(out,in) \
     ~((((in##_GROUP & GROUP_A) >> LOG_GROUP_A) * MASK_A \
       |((in##_GROUP & GROUP_B) >> LOG_GROUP_B) * MASK_B \
       |((in##_GROUP & GROUP_C) >> LOG_GROUP_C) * MASK_C \
       |((in##_GROUP & GROUP_D) >> LOG_GROUP_D) * MASK_D \
       |((in##_GROUP & GROUP_E) >> LOG_GROUP_E) * MASK_E \
       |((in##_GROUP & GROUP_F) >> LOG_GROUP_F) * MASK_F \
       |((in##_GROUP & GROUP_G) >> LOG_GROUP_G) * MASK_G \
       |((in##_GROUP & GROUP_H) >> LOG_GROUP_H) * MASK_H \
       |((in##_GROUP & GROUP_I) >> LOG_GROUP_I) * MASK_I \
       |((in##_GROUP & GROUP_A2)>> LOG_GROUP_A2)* MASK_A2\
       |((in##_GROUP & GROUP_B2)>> LOG_GROUP_B2)* MASK_B2\
       |((in##_GROUP & GROUP_C2)>> LOG_GROUP_C2)* MASK_C2) << in##_SHIFT)

/*
**   Macro: sru_check
**   Creates the bit field for a given input and output signal to test for
**   errors. Returns 0 if the routing is invalid
*/
#define sru_check(out,in) \
    ((((in##_GROUP & GROUP_A) >> LOG_GROUP_A)*0xFF) & ~A_##out \
    |(((in##_GROUP & GROUP_B) >> LOG_GROUP_B)*0xFF) & ~B_##out \
    |(((in##_GROUP & GROUP_C) >> LOG_GROUP_C)*0xFF) & ~C_##out \
    |(((in##_GROUP & GROUP_D) >> LOG_GROUP_D)*0xFF) & ~D_##out \
    |(((in##_GROUP & GROUP_E) >> LOG_GROUP_E)*0xFF) & ~E_##out \
    |(((in##_GROUP & GROUP_F) >> LOG_GROUP_F)*0xFF) & ~F_##out \
    |(((in##_GROUP & GROUP_G) >> LOG_GROUP_G)*0xFF) & ~G_##out \
    |(((in##_GROUP & GROUP_H) >> LOG_GROUP_H)*0xFF) & ~H_##out \
    |(((in##_GROUP & GROUP_I) >> LOG_GROUP_I)*0xFF) & ~I_##out \
    |(((in##_GROUP & GROUP_A2)>> LOG_GROUP_A2)*0xFF) & ~A2_##out \
    |(((in##_GROUP & GROUP_B2)>> LOG_GROUP_B2)*0xFF) & ~B2_##out \
    |(((in##_GROUP & GROUP_C2)>> LOG_GROUP_C2)*0xFF) & ~C2_##out )


/*  Logarithm of Group ID Numbers */
#define LOG_GROUP_A     0
#define LOG_GROUP_B     1
#define LOG_GROUP_C     2
#define LOG_GROUP_D     3
#define LOG_GROUP_E     4
#define LOG_GROUP_F     5
#define LOG_GROUP_G     6
#define LOG_GROUP_A2    7
#define LOG_GROUP_B2    8
#define LOG_GROUP_C2    9
#define LOG_GROUP_H     10
#define LOG_GROUP_I     11


/*  Group ID numbers */
#define GROUP_A         (0x01 << LOG_GROUP_A)
#define GROUP_B         (0x01 << LOG_GROUP_B)
#define GROUP_C         (0x01 << LOG_GROUP_C)
#define GROUP_D         (0x01 << LOG_GROUP_D)
#define GROUP_E         (0x01 << LOG_GROUP_E)
#define GROUP_F         (0x01 << LOG_GROUP_F)
#define GROUP_G         (0x01 << LOG_GROUP_G)
#define GROUP_H         (0x01 << LOG_GROUP_H)
#define GROUP_I         (0x01 << LOG_GROUP_I)
#define GROUP_A2        (0x01 << LOG_GROUP_A2)
#define GROUP_B2        (0x01 << LOG_GROUP_B2)
#define GROUP_C2        (0x01 << LOG_GROUP_C2)

/*  Group Base Masks
**  The actual field masks can be computed by shifting them to the proper
**  location
*/
#define MASK_A          0x1f
#define MASK_B          0x3f
#define MASK_C          0x1f
#define MASK_D          0x7f
#define MASK_E          0x1f
#define MASK_F          0x3f
#define MASK_G          0x01
#define MASK_H          0x1f
#define MASK_I          0x1f
#define MASK_A2         0x1f
#define MASK_B2         0x3f
#define MASK_C2         0x3f


/*============================================================================*/
/*   Group A - Serial Clock Signals                                           */
/* ===========================================================================*/

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
#define SPORT0_CLK_I_GROUP      GROUP_A
#define SPORT1_CLK_I_GROUP      GROUP_A
#define SPORT2_CLK_I_GROUP      GROUP_A
#define SPORT3_CLK_I_GROUP      GROUP_A
#define SPORT4_CLK_I_GROUP      GROUP_A
#define SPORT5_CLK_I_GROUP      GROUP_A

#define SRC0_CLK_IP_I_GROUP     GROUP_A
#define SRC1_CLK_IP_I_GROUP     GROUP_A
#define SRC2_CLK_IP_I_GROUP     GROUP_A
#define SRC3_CLK_IP_I_GROUP     GROUP_A
#define SRC0_CLK_OP_I_GROUP     GROUP_A
#define SRC1_CLK_OP_I_GROUP     GROUP_A
#define SRC2_CLK_OP_I_GROUP     GROUP_A
#define SRC3_CLK_OP_I_GROUP     GROUP_A

#define DIT_CLK_I_GROUP         GROUP_A

#define PDAP_CLK_I_GROUP        GROUP_A  /* is this included because it is not there in the register definition */
#define IDP0_CLK_I_GROUP        GROUP_A
#define IDP1_CLK_I_GROUP        GROUP_A
#define IDP2_CLK_I_GROUP        GROUP_A

#define IDP3_CLK_I_GROUP        GROUP_A
#define IDP4_CLK_I_GROUP        GROUP_A
#define IDP5_CLK_I_GROUP        GROUP_A
#define IDP6_CLK_I_GROUP        GROUP_A
#define IDP7_CLK_I_GROUP        GROUP_A

#define DIT_HFCLK_I_GROUP       GROUP_A

#define PCG_EXTA_I_GROUP        GROUP_A
#define PCG_EXTB_I_GROUP        GROUP_A

#define PCG_SYNC_CLKA_I_GROUP   GROUP_A
#define PCG_SYNC_CLKB_I_GROUP   GROUP_A

#define SPORT6_CLK_I_GROUP      GROUP_A
#define SPORT7_CLK_I_GROUP      GROUP_A

#define PCG_SYNC_CLKC_I_GROUP   GROUP_A
#define PCG_SYNC_CLKD_I_GROUP   GROUP_A

#define PCG_EXTC_I_GROUP        GROUP_A
#define PCG_EXTD_I_GROUP        GROUP_A

#define SPDIF_PLLCLK_I_GROUP    GROUP_A
#define DIT_SYNC_I_GROUP    GROUP_A /*  not sure the naming is correct does EXT is to be included in the name and I has to be written */


/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */
#define SPORT0_CLK_I_REG        SRU_CLK0
#define SPORT1_CLK_I_REG        SRU_CLK0
#define SPORT2_CLK_I_REG        SRU_CLK0
#define SPORT3_CLK_I_REG        SRU_CLK0
#define SPORT4_CLK_I_REG        SRU_CLK0
#define SPORT5_CLK_I_REG        SRU_CLK0

#define SRC0_CLK_IP_I_REG       SRU_CLK1
#define SRC0_CLK_OP_I_REG       SRU_CLK1
#define SRC1_CLK_IP_I_REG       SRU_CLK1
#define SRC1_CLK_OP_I_REG       SRU_CLK1
#define SRC2_CLK_IP_I_REG       SRU_CLK1
#define SRC2_CLK_OP_I_REG       SRU_CLK1

#define SRC3_CLK_IP_I_REG       SRU_CLK2
#define SRC3_CLK_OP_I_REG       SRU_CLK2
#define DIT_CLK_I_REG           SRU_CLK2
#define PDAP_CLK_I_REG          SRU_CLK2 /*  again is it to be included */
#define IDP0_CLK_I_REG          SRU_CLK2
#define IDP1_CLK_I_REG          SRU_CLK2
#define IDP2_CLK_I_REG          SRU_CLK2

#define IDP3_CLK_I_REG          SRU_CLK3
#define IDP4_CLK_I_REG          SRU_CLK3
#define IDP5_CLK_I_REG          SRU_CLK3
#define IDP6_CLK_I_REG          SRU_CLK3
#define IDP7_CLK_I_REG          SRU_CLK3
#define DIT_HFCLK_I_REG         SRU_CLK3

#define PCG_EXTA_I_REG          SRU_CLK4
#define PCG_EXTB_I_REG          SRU_CLK4
#define SPDIF_PLLCLK_I_REG      SRU_CLK4
#define DIT_SYNC_I_REG          SRU_CLK4
#define PCG_SYNC_CLKA_I_REG     SRU_CLK4
#define PCG_SYNC_CLKB_I_REG     SRU_CLK4

#define SPORT6_CLK_I_REG        SRU_CLK5
#define SPORT7_CLK_I_REG        SRU_CLK5
#define PCG_SYNC_CLKC_I_REG     SRU_CLK5
#define PCG_SYNC_CLKD_I_REG     SRU_CLK5
#define PCG_EXTC_I_REG          SRU_CLK5
#define PCG_EXTD_I_REG          SRU_CLK5

/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

/*  SRU_CLK0 */
#define SPORT0_CLK_I_SHIFT      0
#define SPORT1_CLK_I_SHIFT      5
#define SPORT2_CLK_I_SHIFT      10
#define SPORT3_CLK_I_SHIFT      15
#define SPORT4_CLK_I_SHIFT      20
#define SPORT5_CLK_I_SHIFT      25

/* SRU_CLK1 */
#define SRC0_CLK_IP_I_SHIFT     0
#define SRC0_CLK_OP_I_SHIFT     5
#define SRC1_CLK_IP_I_SHIFT     10
#define SRC1_CLK_OP_I_SHIFT     15
#define SRC2_CLK_IP_I_SHIFT     20
#define SRC2_CLK_OP_I_SHIFT     25

/* SRU_CLK2 */
#define SRC3_CLK_IP_I_SHIFT     0
#define SRC3_CLK_OP_I_SHIFT     5
#define DIT_CLK_I_SHIFT         10
#define PDAP_CLK_I_SHIFT        15
#define IDP0_CLK_I_SHIFT        15
#define IDP1_CLK_I_SHIFT        20
#define IDP2_CLK_I_SHIFT        25

/*  SRU_CLK3 */
#define IDP3_CLK_I_SHIFT        0
#define IDP4_CLK_I_SHIFT        5
#define IDP5_CLK_I_SHIFT        10
#define IDP6_CLK_I_SHIFT        15
#define IDP7_CLK_I_SHIFT        20
#define DIT_HFCLK_I_SHIFT       25

/*  SRU_CLK4 */
#define PCG_EXTA_I_SHIFT        0
#define PCG_EXTB_I_SHIFT        5
#define SPDIF_PLLCLK_I_SHIFT    10
#define DIT_SYNC_I_SHIFT        15
#define PCG_SYNC_CLKA_I_SHIFT   20
#define PCG_SYNC_CLKB_I_SHIFT   25

/*  SRU_CLK5 */
#define SPORT6_CLK_I_SHIFT      0
#define SPORT7_CLK_I_SHIFT      5
#define PCG_SYNC_CLKC_I_SHIFT   10
#define PCG_SYNC_CLKD_I_SHIFT   15
#define PCG_EXTC_I_SHIFT        20
#define PCG_EXTD_I_SHIFT        25

/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */
#define A_DAI_PB01_O            0x00
#define A_DAI_PB02_O            0x01
#define A_DAI_PB03_O            0x02
#define A_DAI_PB04_O            0x03
#define A_DAI_PB05_O            0x04
#define A_DAI_PB06_O            0x05
#define A_DAI_PB07_O            0x06
#define A_DAI_PB08_O            0x07
#define A_DAI_PB09_O            0x08
#define A_DAI_PB10_O            0x09
#define A_DAI_PB11_O            0x0a
#define A_DAI_PB12_O            0x0b
#define A_DAI_PB13_O            0x0c
#define A_DAI_PB14_O            0x0d
#define A_DAI_PB15_O            0x0e
#define A_DAI_PB16_O            0x0f
#define A_DAI_PB17_O            0x10
#define A_DAI_PB18_O            0x11
#define A_DAI_PB19_O            0x12
#define A_DAI_PB20_O            0x13
#define A_SPORT0_CLK_O          0x14
#define A_SPORT1_CLK_O          0x15
#define A_SPORT2_CLK_O          0x16
#define A_SPORT3_CLK_O          0x17
#define A_SPORT4_CLK_O          0x18
#define A_SPORT5_CLK_O          0x19
#define A_DIR_CLK_O             0x1a
#define A_DIR_TDMCLK_O          0x1b
#define A_PCG_CLKA_O            0x1c
#define A_PCG_CLKB_O            0x1d
#define A_LOW                   0x1e
#define A_HIGH                  0x1f

/*============================================================================*/
/*   Group B - Serial Data Signals                                            */
/* ===========================================================================*/

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
#define SPORT0_DA_I_GROUP       GROUP_B
#define SPORT0_DB_I_GROUP       GROUP_B
#define SPORT1_DA_I_GROUP       GROUP_B
#define SPORT1_DB_I_GROUP       GROUP_B
#define SPORT2_DA_I_GROUP       GROUP_B
#define SPORT2_DB_I_GROUP       GROUP_B

#define SPORT3_DA_I_GROUP       GROUP_B
#define SPORT3_DB_I_GROUP       GROUP_B
#define SPORT4_DA_I_GROUP       GROUP_B
#define SPORT4_DB_I_GROUP       GROUP_B
#define SPORT5_DA_I_GROUP       GROUP_B
#define SPORT5_DB_I_GROUP       GROUP_B

#define SRC0_DAT_IP_I_GROUP     GROUP_B
#define SRC1_DAT_IP_I_GROUP     GROUP_B
#define SRC2_DAT_IP_I_GROUP     GROUP_B
#define SRC3_DAT_IP_I_GROUP     GROUP_B
#define SRC0_TDM_OP_I_GROUP     GROUP_B
#define SRC1_TDM_OP_I_GROUP     GROUP_B
#define SRC2_TDM_OP_I_GROUP     GROUP_B
#define SRC3_TDM_OP_I_GROUP     GROUP_B

#define DIT_DAT_I_GROUP         GROUP_B
#define IDP0_DAT_I_GROUP        GROUP_B
#define IDP1_DAT_I_GROUP        GROUP_B
#define IDP2_DAT_I_GROUP        GROUP_B
#define IDP3_DAT_I_GROUP        GROUP_B
#define IDP4_DAT_I_GROUP        GROUP_B
#define IDP5_DAT_I_GROUP        GROUP_B
#define IDP6_DAT_I_GROUP        GROUP_B
#define IDP7_DAT_I_GROUP        GROUP_B

#define DIR_I_GROUP             GROUP_B
#define SPORT6_DA_I_GROUP       GROUP_B
#define SPORT6_DB_I_GROUP       GROUP_B
#define SPORT7_DA_I_GROUP       GROUP_B
#define SPORT7_DB_I_GROUP       GROUP_B

/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */
#define SPORT0_DA_I_REG         SRU_DAT0
#define SPORT0_DB_I_REG         SRU_DAT0
#define SPORT1_DA_I_REG         SRU_DAT0
#define SPORT1_DB_I_REG         SRU_DAT0
#define SPORT2_DA_I_REG         SRU_DAT0

#define SPORT2_DB_I_REG         SRU_DAT1
#define SPORT3_DA_I_REG         SRU_DAT1
#define SPORT3_DB_I_REG         SRU_DAT1
#define SPORT4_DA_I_REG         SRU_DAT1
#define SPORT4_DB_I_REG         SRU_DAT1

#define SPORT5_DA_I_REG         SRU_DAT2
#define SPORT5_DB_I_REG         SRU_DAT2
#define SRC0_DAT_IP_I_REG       SRU_DAT2
#define SRC1_DAT_IP_I_REG       SRU_DAT2
#define SRC2_DAT_IP_I_REG       SRU_DAT2

#define SRC3_DAT_IP_I_REG       SRU_DAT3
#define SRC0_TDM_OP_I_REG       SRU_DAT3
#define SRC1_TDM_OP_I_REG       SRU_DAT3
#define SRC2_TDM_OP_I_REG       SRU_DAT3
#define SRC3_TDM_OP_I_REG       SRU_DAT3

#define DIT_DAT_I_REG           SRU_DAT4
#define IDP0_DAT_I_REG          SRU_DAT4
#define IDP1_DAT_I_REG          SRU_DAT4
#define IDP2_DAT_I_REG          SRU_DAT4
#define IDP3_DAT_I_REG          SRU_DAT4

#define IDP4_DAT_I_REG          SRU_DAT5
#define IDP5_DAT_I_REG          SRU_DAT5
#define IDP6_DAT_I_REG          SRU_DAT5
#define IDP7_DAT_I_REG          SRU_DAT5
#define DIR_I_REG               SRU_DAT5

#define SPORT6_DA_I_REG         SRU_DAT6
#define SPORT6_DB_I_REG         SRU_DAT6
#define SPORT7_DA_I_REG         SRU_DAT6
#define SPORT7_DB_I_REG         SRU_DAT6

/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

/*  SRU_DAT0 */
#define SPORT0_DA_I_SHIFT       0
#define SPORT0_DB_I_SHIFT       6
#define SPORT1_DA_I_SHIFT       12
#define SPORT1_DB_I_SHIFT       18
#define SPORT2_DA_I_SHIFT       24

/*  SRU_DAT1 */
#define SPORT2_DB_I_SHIFT       0
#define SPORT3_DA_I_SHIFT       6
#define SPORT3_DB_I_SHIFT       12
#define SPORT4_DA_I_SHIFT       18
#define SPORT4_DB_I_SHIFT       24

/*  SRU_DAT2 */
#define SPORT5_DA_I_SHIFT       0
#define SPORT5_DB_I_SHIFT       6
#define SRC0_DAT_IP_I_SHIFT     12
#define SRC1_DAT_IP_I_SHIFT     18
#define SRC2_DAT_IP_I_SHIFT     24

/*SRU DAT3 */
#define SRC3_DAT_IP_I_SHIFT     0
#define SRC0_TDM_OP_I_SHIFT     6
#define SRC1_TDM_OP_I_SHIFT     12
#define SRC2_TDM_OP_I_SHIFT     18
#define SRC3_TDM_OP_I_SHIFT     24


/*  SRU_DAT4 */
#define DIT_DAT_I_SHIFT         0
#define IDP0_DAT_I_SHIFT        6
#define IDP1_DAT_I_SHIFT        12
#define IDP2_DAT_I_SHIFT        18
#define IDP3_DAT_I_SHIFT        24

/*  SRU_DAT5 */
#define IDP4_DAT_I_SHIFT        0
#define IDP5_DAT_I_SHIFT        6
#define IDP6_DAT_I_SHIFT        12
#define IDP7_DAT_I_SHIFT        18
#define DIR_I_SHIFT             24

/*  SRU_DAT6 */
#define SPORT6_DA_I_SHIFT       0
#define SPORT6_DB_I_SHIFT       6
#define SPORT7_DA_I_SHIFT       12
#define SPORT7_DB_I_SHIFT       18

/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */
#define B_DAI_PB01_O            0x00
#define B_DAI_PB02_O            0x01
#define B_DAI_PB03_O            0x02
#define B_DAI_PB04_O            0x03
#define B_DAI_PB05_O            0x04
#define B_DAI_PB06_O            0x05
#define B_DAI_PB07_O            0x06
#define B_DAI_PB08_O            0x07
#define B_DAI_PB09_O            0x08
#define B_DAI_PB10_O            0x09
#define B_DAI_PB11_O            0x0a
#define B_DAI_PB12_O            0x0b
#define B_DAI_PB13_O            0x0c
#define B_DAI_PB14_O            0x0d
#define B_DAI_PB15_O            0x0e
#define B_DAI_PB16_O            0x0f
#define B_DAI_PB17_O            0x10
#define B_DAI_PB18_O            0x11
#define B_DAI_PB19_O            0x12
#define B_DAI_PB20_O            0x13
#define B_SPORT0_DA_O           0x14
#define B_SPORT0_DB_O           0x15
#define B_SPORT1_DA_O           0x16
#define B_SPORT1_DB_O           0x17
#define B_SPORT2_DA_O           0x18
#define B_SPORT2_DB_O           0x19
#define B_SPORT3_DA_O           0x1a
#define B_SPORT3_DB_O           0x1b
#define B_SPORT4_DA_O           0x1c
#define B_SPORT4_DB_O           0x1d
#define B_SPORT5_DA_O           0x1e
#define B_SPORT5_DB_O           0x1f

#define B_SRC0_DAT_OP_O         0x20
#define B_SRC1_DAT_OP_O         0x21
#define B_SRC2_DAT_OP_O         0x22
#define B_SRC3_DAT_OP_O         0x23
#define B_SRC0_TDM_IP_O         0x24
#define B_SRC1_TDM_IP_O         0x25
#define B_SRC2_TDM_IP_O         0x26
#define B_SRC3_TDM_IP_O         0x27

#define B_DIR_DAT_O             0x28
#define B_SPORT6_DA_O           0x2c
#define B_SPORT6_DB_O           0x2d
#define B_SPORT7_DA_O           0x2e
#define B_SPORT7_DB_O           0x2f
#define B_DIT_O                 0x30
#define B_LOW                   0x3e
#define B_HIGH                  0x3f

/*============================================================================*/
/*   Group C - Fame Sync Signals                                              */
/* ===========================================================================*/

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
#define SPORT0_FS_I_GROUP       GROUP_C
#define SPORT1_FS_I_GROUP       GROUP_C
#define SPORT2_FS_I_GROUP       GROUP_C
#define SPORT3_FS_I_GROUP       GROUP_C
#define SPORT4_FS_I_GROUP       GROUP_C
#define SPORT5_FS_I_GROUP       GROUP_C

#define SRC0_FS_IP_I_GROUP      GROUP_C
#define SRC0_FS_OP_I_GROUP      GROUP_C
#define SRC1_FS_IP_I_GROUP      GROUP_C
#define SRC1_FS_OP_I_GROUP      GROUP_C
#define SRC2_FS_IP_I_GROUP      GROUP_C
#define SRC2_FS_OP_I_GROUP      GROUP_C
#define SRC3_FS_IP_I_GROUP      GROUP_C
#define SRC3_FS_OP_I_GROUP      GROUP_C

#define DIT_FS_I_GROUP          GROUP_C
#define PDAP_HOLD_I_GROUP       GROUP_C
#define IDP0_FS_I_GROUP         GROUP_C
#define IDP1_FS_I_GROUP         GROUP_C
#define IDP2_FS_I_GROUP         GROUP_C

#define IDP3_FS_I_GROUP         GROUP_C
#define IDP4_FS_I_GROUP         GROUP_C
#define IDP5_FS_I_GROUP         GROUP_C
#define IDP6_FS_I_GROUP         GROUP_C
#define IDP7_FS_I_GROUP         GROUP_C

#define SPORT6_FS_I_GROUP       GROUP_C
#define SPORT7_FS_I_GROUP       GROUP_C

/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */
#define SPORT0_FS_I_REG         SRU_FS0
#define SPORT1_FS_I_REG         SRU_FS0
#define SPORT2_FS_I_REG         SRU_FS0
#define SPORT3_FS_I_REG         SRU_FS0
#define SPORT4_FS_I_REG         SRU_FS0
#define SPORT5_FS_I_REG         SRU_FS0

#define SRC0_FS_IP_I_REG        SRU_FS1
#define SRC0_FS_OP_I_REG        SRU_FS1
#define SRC1_FS_IP_I_REG        SRU_FS1
#define SRC1_FS_OP_I_REG        SRU_FS1
#define SRC2_FS_IP_I_REG        SRU_FS1
#define SRC2_FS_OP_I_REG        SRU_FS1

#define SRC3_FS_IP_I_REG        SRU_FS2
#define SRC3_FS_OP_I_REG        SRU_FS2
#define DIT_FS_I_REG            SRU_FS2
#define PDAP_HOLD_I_REG         SRU_FS2
#define IDP0_FS_I_REG           SRU_FS2
#define IDP1_FS_I_REG           SRU_FS2
#define IDP2_FS_I_REG           SRU_FS2

#define IDP3_FS_I_REG           SRU_FS3
#define IDP4_FS_I_REG           SRU_FS3
#define IDP5_FS_I_REG           SRU_FS3
#define IDP6_FS_I_REG           SRU_FS3
#define IDP7_FS_I_REG           SRU_FS3

#define SPORT6_FS_I_REG         SRU_FS4
#define SPORT7_FS_I_REG         SRU_FS4

/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

/*  SRU_FS0 */
#define SPORT0_FS_I_SHIFT       0
#define SPORT1_FS_I_SHIFT       5
#define SPORT2_FS_I_SHIFT       10
#define SPORT3_FS_I_SHIFT       15
#define SPORT4_FS_I_SHIFT       20
#define SPORT5_FS_I_SHIFT       25

/* SRU_FS1 */
#define SRC0_FS_IP_I_SHIFT      0
#define SRC0_FS_OP_I_SHIFT      5
#define SRC1_FS_IP_I_SHIFT      10
#define SRC1_FS_OP_I_SHIFT      15
#define SRC2_FS_IP_I_SHIFT      20
#define SRC2_FS_OP_I_SHIFT      25

/* SRU_FS2 */
#define SRC3_FS_IP_I_SHIFT      0
#define SRC3_FS_OP_I_SHIFT      5
#define DIT_FS_I_SHIFT          10
#define PDAP_HOLD_I_SHIFT       15
#define IDP0_FS_I_SHIFT         15
#define IDP1_FS_I_SHIFT         20
#define IDP2_FS_I_SHIFT         25


/*  SRU_FS3 */
#define IDP3_FS_I_SHIFT         0
#define IDP4_FS_I_SHIFT         5
#define IDP5_FS_I_SHIFT         10
#define IDP6_FS_I_SHIFT         15
#define IDP7_FS_I_SHIFT         20

/* SRU_FS4 */
#define SPORT6_FS_I_SHIFT       0
#define SPORT7_FS_I_SHIFT       5

/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */
#define C_DAI_PB01_O            0x00
#define C_DAI_PB02_O            0x01
#define C_DAI_PB03_O            0x02
#define C_DAI_PB04_O            0x03
#define C_DAI_PB05_O            0x04
#define C_DAI_PB06_O            0x05
#define C_DAI_PB07_O            0x06
#define C_DAI_PB08_O            0x07
#define C_DAI_PB09_O            0x08
#define C_DAI_PB10_O            0x09
#define C_DAI_PB11_O            0x0a
#define C_DAI_PB12_O            0x0b
#define C_DAI_PB13_O            0x0c
#define C_DAI_PB14_O            0x0d
#define C_DAI_PB15_O            0x0e
#define C_DAI_PB16_O            0x0f
#define C_DAI_PB17_O            0x10
#define C_DAI_PB18_O            0x11
#define C_DAI_PB19_O            0x12
#define C_DAI_PB20_O            0x13
#define C_SPORT0_FS_O           0x14
#define C_SPORT1_FS_O           0x15
#define C_SPORT2_FS_O           0x16
#define C_SPORT3_FS_O           0x17
#define C_SPORT4_FS_O           0x18
#define C_SPORT5_FS_O           0x19
#define C_DIR_FS_O              0x1a

#define C_PCG_FSA_O             0x1c
#define C_PCG_FSB_O             0x1d
#define C_LOW                   0x1e
#define C_HIGH                  0x1f

/*============================================================================*/
/*   Group D - Pin Input Signals */
/* ===========================================================================*/

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
#define DAI_PB01_I_GROUP        GROUP_D
#define DAI_PB02_I_GROUP        GROUP_D
#define DAI_PB03_I_GROUP        GROUP_D
#define DAI_PB04_I_GROUP        GROUP_D
#define DAI_PB05_I_GROUP        GROUP_D

#define DAI_PB06_I_GROUP        GROUP_D
#define DAI_PB07_I_GROUP        GROUP_D
#define DAI_PB08_I_GROUP        GROUP_D
#define DAI_PB09_I_GROUP        GROUP_D
#define DAI_PB10_I_GROUP        GROUP_D

#define DAI_PB11_I_GROUP        GROUP_D
#define DAI_PB12_I_GROUP        GROUP_D
#define DAI_PB13_I_GROUP        GROUP_D
#define DAI_PB14_I_GROUP        GROUP_D
#define DAI_PB15_I_GROUP        GROUP_D

#define DAI_PB16_I_GROUP        GROUP_D
#define DAI_PB17_I_GROUP        GROUP_D
#define DAI_PB18_I_GROUP        GROUP_D
#define DAI_PB19_I_GROUP        GROUP_D
#define DAI_PB20_I_GROUP        GROUP_D


/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */
#define DAI_PB01_I_REG          SRU_PIN0
#define DAI_PB02_I_REG          SRU_PIN0
#define DAI_PB03_I_REG          SRU_PIN0
#define DAI_PB04_I_REG          SRU_PIN0

#define DAI_PB05_I_REG          SRU_PIN1
#define DAI_PB06_I_REG          SRU_PIN1
#define DAI_PB07_I_REG          SRU_PIN1
#define DAI_PB08_I_REG          SRU_PIN1

#define DAI_PB09_I_REG          SRU_PIN2
#define DAI_PB10_I_REG          SRU_PIN2
#define DAI_PB11_I_REG          SRU_PIN2
#define DAI_PB12_I_REG          SRU_PIN2

#define DAI_PB13_I_REG          SRU_PIN3
#define DAI_PB14_I_REG          SRU_PIN3
#define DAI_PB15_I_REG          SRU_PIN3
#define DAI_PB16_I_REG          SRU_PIN3

#define DAI_PB17_I_REG          SRU_PIN4
#define DAI_PB18_I_REG          SRU_PIN4
#define DAI_PB19_I_REG          SRU_PIN4
#define DAI_PB20_I_REG          SRU_PIN4


/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

/*  SRU_PIN0 */
#define DAI_PB01_I_SHIFT        0
#define DAI_PB02_I_SHIFT        7
#define DAI_PB03_I_SHIFT        14
#define DAI_PB04_I_SHIFT        21

/*  SRU_PIN1 */
#define DAI_PB05_I_SHIFT        0
#define DAI_PB06_I_SHIFT        7
#define DAI_PB07_I_SHIFT        14
#define DAI_PB08_I_SHIFT        21

/*  SRU_PIN2 */
#define DAI_PB09_I_SHIFT        0
#define DAI_PB10_I_SHIFT        7
#define DAI_PB11_I_SHIFT        14
#define DAI_PB12_I_SHIFT        21

/*  SRU_PIN3 */
#define DAI_PB13_I_SHIFT        0
#define DAI_PB14_I_SHIFT        7
#define DAI_PB15_I_SHIFT        14
#define DAI_PB16_I_SHIFT        21

/* SRU_PIN4 */
#define DAI_PB17_I_SHIFT        0
#define DAI_PB18_I_SHIFT        7
#define DAI_PB19_I_SHIFT        14
#define DAI_PB20_I_SHIFT        21


/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */
#define D_DAI_PB01_O            0x00
#define D_DAI_PB02_O            0x01
#define D_DAI_PB03_O            0x02
#define D_DAI_PB04_O            0x03
#define D_DAI_PB05_O            0x04
#define D_DAI_PB06_O            0x05
#define D_DAI_PB07_O            0x06
#define D_DAI_PB08_O            0x07
#define D_DAI_PB09_O            0x08
#define D_DAI_PB10_O            0x09
#define D_DAI_PB11_O            0x0a
#define D_DAI_PB12_O            0x0b
#define D_DAI_PB13_O            0x0c
#define D_DAI_PB14_O            0x0d
#define D_DAI_PB15_O            0x0e
#define D_DAI_PB16_O            0x0f
#define D_DAI_PB17_O            0x10
#define D_DAI_PB18_O            0x11
#define D_DAI_PB19_O            0x12
#define D_DAI_PB20_O            0x13
#define D_SPORT0_DA_O           0x14
#define D_SPORT0_DB_O           0x15
#define D_SPORT1_DA_O           0x16
#define D_SPORT1_DB_O           0x17
#define D_SPORT2_DA_O           0x18
#define D_SPORT2_DB_O           0x19
#define D_SPORT3_DA_O           0x1a
#define D_SPORT3_DB_O           0x1b
#define D_SPORT4_DA_O           0x1c
#define D_SPORT4_DB_O           0x1d
#define D_SPORT5_DA_O           0x1e
#define D_SPORT5_DB_O           0x1f
#define D_SPORT0_CLK_O          0x20
#define D_SPORT1_CLK_O          0x21
#define D_SPORT2_CLK_O          0x22
#define D_SPORT3_CLK_O          0x23
#define D_SPORT4_CLK_O          0x24
#define D_SPORT5_CLK_O          0x25
#define D_SPORT0_FS_O           0x26
#define D_SPORT1_FS_O           0x27
#define D_SPORT2_FS_O           0x28
#define D_SPORT3_FS_O           0x29
#define D_SPORT4_FS_O           0x2a
#define D_SPORT5_FS_O           0x2b
#define D_SPORT6_DA_O           0x2c
#define D_SPORT6_DB_O           0x2d
#define D_SPORT7_DA_O           0x2e
#define D_SPORT7_DB_O           0x2f
#define D_PDAP_STRB_O           0x30
#define D_BLK_START_O           0x31
#define D_SPORT6_CLK_O          0x34
#define D_SPORT7_CLK_O          0x35
#define D_SPORT6_FS_O           0x36
#define D_SPORT7_FS_O           0x37
#define D_PCG_CLKA_O            0x38
#define D_PCG_CLKB_O            0x39
#define D_PCG_FSA_O             0x3a
#define D_PCG_FSB_O             0x3b
#define D_SRC0_DAT_OP_O         0x3d
#define D_SRC1_DAT_OP_O         0x3e
#define D_SRC2_DAT_OP_O         0x3f
#define D_SRC3_DAT_OP_O         0x40

#define D_DIR_DAT_O             0x41
#define D_DIR_FS_O              0x42
#define D_DIR_CLK_O             0x43
#define D_DIR_TDMCLK_O          0x44
#define D_DIT_O                 0x45
#define D_SPORT0_TDV_O          0x46
#define D_SPORT1_TDV_O          0x47
#define D_SPORT2_TDV_O          0x48
#define D_SPORT3_TDV_O          0x49
#define D_SPORT4_TDV_O          0x4a
#define D_SPORT5_TDV_O          0x4b
#define D_SPORT6_TDV_O          0x4c
#define D_SPORT7_TDV_O          0x4d
#define D_DIR_LRCLK_REF_O       0x4e
#define D_DIR_LRCLK_FB_O        0x4f
#define D_PCG_CLKC_O            0x50
#define D_PCG_CLKD_O            0x51
#define D_PCG_FSC_O             0x52
#define D_PCG_FSD_O             0x53
#define D_LOW                   0x7e
#define D_HIGH                  0x7f



/*============================================================================*/
/*   Group E - Miscellaneous SRU Signals */
/*============================================================================*/

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
#define MISCA0_I_GROUP          GROUP_E
#define DAI_INT_28_I_GROUP      GROUP_E
#define MISCA1_I_GROUP          GROUP_E
#define DAI_INT_29_I_GROUP      GROUP_E
#define MISCA2_I_GROUP          GROUP_E
#define DAI_INT_30_I_GROUP      GROUP_E
#define MISCA3_I_GROUP          GROUP_E
#define DAI_INT_31_I_GROUP      GROUP_E
#define MISCA4_I_GROUP          GROUP_E
#define MISCA5_I_GROUP          GROUP_E
#define DAI_INT_22_I_GROUP      GROUP_E
#define DAI_INT_23_I_GROUP      GROUP_E
#define DAI_INT_24_I_GROUP      GROUP_E
#define DAI_INT_25_I_GROUP      GROUP_E
#define DAI_INT_26_I_GROUP      GROUP_E
#define DAI_INT_27_I_GROUP      GROUP_E

#define INV_MISCA4_I_GROUP      GROUP_G
#define INV_MISCA5_I_GROUP      GROUP_G





/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */
#define MISCA0_I_REG            SRU_EXT_MISCA
#define DAI_INT_28_I_REG        SRU_EXT_MISCA
#define MISCA1_I_REG            SRU_EXT_MISCA
#define DAI_INT_29_I_REG        SRU_EXT_MISCA
#define MISCA2_I_REG            SRU_EXT_MISCA
#define DAI_INT_30_I_REG        SRU_EXT_MISCA
#define MISCA3_I_REG            SRU_EXT_MISCA
#define DAI_INT_31_I_REG        SRU_EXT_MISCA
#define MISCA4_I_REG            SRU_EXT_MISCA
#define MISCA5_I_REG            SRU_EXT_MISCA

#define DAI_INT_22_I_REG        SRU_EXT_MISCB
#define DAI_INT_23_I_REG        SRU_EXT_MISCB
#define DAI_INT_24_I_REG        SRU_EXT_MISCB
#define DAI_INT_25_I_REG        SRU_EXT_MISCB
#define DAI_INT_26_I_REG        SRU_EXT_MISCB
#define DAI_INT_27_I_REG        SRU_EXT_MISCB

#define INV_MISCA4_I_REG        SRU_EXT_MISCA
#define INV_MISCA5_I_REG        SRU_EXT_MISCA


/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

/*  SRU_EXT_MISCA */
#define MISCA0_I_SHIFT          0
#define DAI_INT_28_I_SHIFT      0
#define MISCA1_I_SHIFT          5
#define DAI_INT_29_I_SHIFT      5
#define MISCA2_I_SHIFT          10
#define DAI_INT_30_I_SHIFT      10
#define MISCA3_I_SHIFT          15
#define DAI_INT_31_I_SHIFT      15
#define MISCA4_I_SHIFT          20
#define MISCA5_I_SHIFT          25


#define INV_MISCA4_I_SHIFT      30
#define INV_MISCA5_I_SHIFT      31

/*  SRU_EXT_MISCB */
#define DAI_INT_22_I_SHIFT      0
#define DAI_INT_23_I_SHIFT      5
#define DAI_INT_24_I_SHIFT      10
#define DAI_INT_25_I_SHIFT      15
#define DAI_INT_26_I_SHIFT      20
#define DAI_INT_27_I_SHIFT      25


/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */
#define E_DAI_PB01_O            0x00
#define E_DAI_PB02_O            0x01
#define E_DAI_PB03_O            0x02
#define E_DAI_PB04_O            0x03
#define E_DAI_PB05_O            0x04
#define E_DAI_PB06_O            0x05
#define E_DAI_PB07_O            0x06
#define E_DAI_PB08_O            0x07
#define E_DAI_PB09_O            0x08
#define E_DAI_PB10_O            0x09
#define E_DAI_PB11_O            0x0a
#define E_DAI_PB12_O            0x0b
#define E_DAI_PB13_O            0x0c
#define E_DAI_PB14_O            0x0d
#define E_DAI_PB15_O            0x0e
#define E_DAI_PB16_O            0x0f
#define E_DAI_PB17_O            0x10
#define E_DAI_PB18_O            0x11
#define E_DAI_PB19_O            0x12
#define E_DAI_PB20_O            0x13
#define E_SPORT0_FS_O           0x14
#define E_SPORT1_FS_O           0x15
#define E_SPORT2_FS_O           0x16
#define E_SPORT3_FS_O           0x17
#define E_SPORT4_FS_O           0x18
#define E_SPORT5_FS_O           0x19
#define E_BLK_START_O           0x1a
#define E_PCG_FSA_O             0x1b
#define E_PCG_CLKB_O            0x1c
#define E_PCG_FSB_O             0x1d
#define E_LOW                   0x1e
#define E_HIGH                  0x1f

#define G_LOW                   0x00
#define G_HIGH                  0x01


/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
/*   GROUP H Shift Register Clock               */

#define SR_SCLK_I_GROUP     GROUP_H
#define SR_LAT_I_GROUP      GROUP_H

/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */
#define SR_SCLK_I_REG          SRU_CLK_SHREG
#define SR_LAT_I_REG           SRU_CLK_SHREG


/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

#define SR_SCLK_I_SHIFT        0
#define SR_LAT_I_SHIFT         5



/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */


#define H_LOW                     0x00
#define H_HIGH                    0x01
#define H_SPORT0_CLK_O            0x02
#define H_SPORT1_CLK_O            0x03
#define H_SPORT2_CLK_O            0x04
#define H_SPORT3_CLK_O            0x05
#define H_SPORT4_CLK_O            0x06
#define H_SPORT5_CLK_O            0x07
#define H_SPORT6_CLK_O            0x08
#define H_SPORT7_CLK_O            0x09
#define H_SPORT0_FS_O             0x0a
#define H_SPORT1_FS_O             0x0b
#define H_SPORT2_FS_O             0x0c
#define H_SPORT3_FS_O             0x0d
#define H_SPORT4_FS_O             0x0e
#define H_SPORT5_FS_O             0x0f
#define H_SPORT6_FS_O             0x10
#define H_SPORT7_FS_O             0x11
#define H_SR_SCLK_O               0x12
#define H_SR_LAT_O                0x13
#define H_PCG_CLKA_O              0x14
#define H_PCG_CLKB_O              0x15
#define H_PCG_FSA_O               0x16
#define H_PCG_FSB_O               0x17
#define H_DAI_PB01_O              0x18
#define H_DAI_PB02_O              0x19
#define H_DAI_PB03_O              0x1a
#define H_DAI_PB04_O              0x1b
#define H_DAI_PB05_O              0x1c
#define H_DAI_PB06_O              0x1d
#define H_DAI_PB07_O              0x1e
#define H_DAI_PB08_O              0x1f

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */
/*   GROUP I Shift Register                     */

#define SR_SDI_I_GROUP     GROUP_I

/* -------------------------------------------- */
/*   Register Assignments */
/* -------------------------------------------- */

#define SR_SDI_I_REG            SRU_DAT_SHREG

/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

#define SR_SDI_I_SHIFT           0


/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */

#define I_LOW                     0x00
#define I_HIGH                    0x01
#define I_SPORT0_DA_O             0x02
#define I_SPORT0_DB_O             0x03
#define I_SPORT1_DA_O             0x04
#define I_SPORT1_DB_O             0x05
#define I_SPORT2_DA_O             0x06
#define I_SPORT2_DB_O             0x07
#define I_SPORT3_DA_O             0x08
#define I_SPORT3_DB_O             0x09
#define I_SPORT4_DA_O             0x0a
#define I_SPORT4_DB_O             0x0b
#define I_SPORT5_DA_O             0x0c
#define I_SPORT5_DB_O             0x0d
#define I_SPORT6_DA_O             0x0e
#define I_SPORT6_DB_O             0x0f
#define I_SPORT7_DA_O             0x10
#define I_SPORT7_DB_O             0x11
#define I_SR_SDAT_O               0x12
#define I_DAI_PB01_O              0x13
#define I_DAI_PB02_O              0x14
#define I_DAI_PB03_O              0x15
#define I_DAI_PB04_O              0x16
#define I_DAI_PB05_O              0x17
#define I_DAI_PB06_O              0x18
#define I_DAI_PB07_O              0x19
#define I_DAI_PB08_O              0x1a




/*============================================================================*/
/*   Group F - Pin Buffer Enable Signals */
/*============================================================================*/

/* -------------------------------------------- */
/*   Group ID Assignments */
/* -------------------------------------------- */

#define PBEN01_I_GROUP      GROUP_F
#define PBEN02_I_GROUP      GROUP_F
#define PBEN03_I_GROUP      GROUP_F
#define PBEN04_I_GROUP      GROUP_F
#define PBEN05_I_GROUP      GROUP_F

#define PBEN06_I_GROUP      GROUP_F
#define PBEN07_I_GROUP      GROUP_F
#define PBEN08_I_GROUP      GROUP_F
#define PBEN09_I_GROUP      GROUP_F
#define PBEN10_I_GROUP      GROUP_F

#define PBEN11_I_GROUP      GROUP_F
#define PBEN12_I_GROUP      GROUP_F
#define PBEN13_I_GROUP      GROUP_F
#define PBEN14_I_GROUP      GROUP_F
#define PBEN15_I_GROUP      GROUP_F

#define PBEN16_I_GROUP      GROUP_F
#define PBEN17_I_GROUP      GROUP_F
#define PBEN18_I_GROUP      GROUP_F
#define PBEN19_I_GROUP      GROUP_F
#define PBEN20_I_GROUP      GROUP_F

/* -------------------------------------------- */
/*   Resister Assignments */
/* -------------------------------------------- */

#define PBEN01_I_REG        SRU_PBEN0
#define PBEN02_I_REG        SRU_PBEN0
#define PBEN03_I_REG        SRU_PBEN0
#define PBEN04_I_REG        SRU_PBEN0
#define PBEN05_I_REG        SRU_PBEN0

#define PBEN06_I_REG        SRU_PBEN1
#define PBEN07_I_REG        SRU_PBEN1
#define PBEN08_I_REG        SRU_PBEN1
#define PBEN09_I_REG        SRU_PBEN1
#define PBEN10_I_REG        SRU_PBEN1

#define PBEN11_I_REG        SRU_PBEN2
#define PBEN12_I_REG        SRU_PBEN2
#define PBEN13_I_REG        SRU_PBEN2
#define PBEN14_I_REG        SRU_PBEN2
#define PBEN15_I_REG        SRU_PBEN2

#define PBEN16_I_REG        SRU_PBEN3
#define PBEN17_I_REG        SRU_PBEN3
#define PBEN18_I_REG        SRU_PBEN3
#define PBEN19_I_REG        SRU_PBEN3
#define PBEN20_I_REG        SRU_PBEN3

/* -------------------------------------------- */
/*   Shift Values for Bit Fields */
/* -------------------------------------------- */

/*  SRU_PBEN0 */
#define PBEN01_I_SHIFT      0
#define PBEN02_I_SHIFT      6
#define PBEN03_I_SHIFT      12
#define PBEN04_I_SHIFT      18
#define PBEN05_I_SHIFT      24

/*  SRU_PBEN1 */
#define PBEN06_I_SHIFT      0
#define PBEN07_I_SHIFT      6
#define PBEN08_I_SHIFT      12
#define PBEN09_I_SHIFT      18
#define PBEN10_I_SHIFT      24

/*  SRU_PBEN2 */
#define PBEN11_I_SHIFT      0
#define PBEN12_I_SHIFT      6
#define PBEN13_I_SHIFT      12
#define PBEN14_I_SHIFT      18
#define PBEN15_I_SHIFT      24

/*  SRU_PBEN3 */
#define PBEN16_I_SHIFT      0
#define PBEN17_I_SHIFT      6
#define PBEN18_I_SHIFT      12
#define PBEN19_I_SHIFT      18
#define PBEN20_I_SHIFT      24

/*-------------------------------------------- */
/*  NEW  definitions to match with the docs */
/* changed to DAI_PBENxx_I  to comply with DPI */
/*-------------------------------------------- */

#define DAI_PBEN01_I_GROUP      GROUP_F
#define DAI_PBEN02_I_GROUP      GROUP_F
#define DAI_PBEN03_I_GROUP      GROUP_F
#define DAI_PBEN04_I_GROUP      GROUP_F
#define DAI_PBEN05_I_GROUP      GROUP_F

#define DAI_PBEN06_I_GROUP      GROUP_F
#define DAI_PBEN07_I_GROUP      GROUP_F
#define DAI_PBEN08_I_GROUP      GROUP_F
#define DAI_PBEN09_I_GROUP      GROUP_F
#define DAI_PBEN10_I_GROUP      GROUP_F

#define DAI_PBEN11_I_GROUP      GROUP_F
#define DAI_PBEN12_I_GROUP      GROUP_F
#define DAI_PBEN13_I_GROUP      GROUP_F
#define DAI_PBEN14_I_GROUP      GROUP_F
#define DAI_PBEN15_I_GROUP      GROUP_F

#define DAI_PBEN16_I_GROUP      GROUP_F
#define DAI_PBEN17_I_GROUP      GROUP_F
#define DAI_PBEN18_I_GROUP      GROUP_F
#define DAI_PBEN19_I_GROUP      GROUP_F
#define DAI_PBEN20_I_GROUP      GROUP_F

/*-------------------------------------------- */
/*  Register Assignments */
/*-------------------------------------------- */

#define DAI_PBEN01_I_REG        SRU_PBEN0
#define DAI_PBEN02_I_REG        SRU_PBEN0
#define DAI_PBEN03_I_REG        SRU_PBEN0
#define DAI_PBEN04_I_REG        SRU_PBEN0
#define DAI_PBEN05_I_REG        SRU_PBEN0

#define DAI_PBEN06_I_REG        SRU_PBEN1
#define DAI_PBEN07_I_REG        SRU_PBEN1
#define DAI_PBEN08_I_REG        SRU_PBEN1
#define DAI_PBEN09_I_REG        SRU_PBEN1
#define DAI_PBEN10_I_REG        SRU_PBEN1

#define DAI_PBEN11_I_REG        SRU_PBEN2
#define DAI_PBEN12_I_REG        SRU_PBEN2
#define DAI_PBEN13_I_REG        SRU_PBEN2
#define DAI_PBEN14_I_REG        SRU_PBEN2
#define DAI_PBEN15_I_REG        SRU_PBEN2

#define DAI_PBEN16_I_REG        SRU_PBEN3
#define DAI_PBEN17_I_REG        SRU_PBEN3
#define DAI_PBEN18_I_REG        SRU_PBEN3
#define DAI_PBEN19_I_REG        SRU_PBEN3
#define DAI_PBEN20_I_REG        SRU_PBEN3

/*-------------------------------------------- */
/*  Shift Values for Bit Fields */
/*-------------------------------------------- */

/* SRU_DAI_PBEN0 */
#define DAI_PBEN01_I_SHIFT      0
#define DAI_PBEN02_I_SHIFT      6
#define DAI_PBEN03_I_SHIFT      12
#define DAI_PBEN04_I_SHIFT      18
#define DAI_PBEN05_I_SHIFT      24

/* SRU_DAI_PBEN1 */
#define DAI_PBEN06_I_SHIFT      0
#define DAI_PBEN07_I_SHIFT      6
#define DAI_PBEN08_I_SHIFT      12
#define DAI_PBEN09_I_SHIFT      18
#define DAI_PBEN10_I_SHIFT      24

/* SRU_DAI_PBEN2 */
#define DAI_PBEN11_I_SHIFT      0
#define DAI_PBEN12_I_SHIFT      6
#define DAI_PBEN13_I_SHIFT      12
#define DAI_PBEN14_I_SHIFT      18
#define DAI_PBEN15_I_SHIFT      24

/* SRU_DAI_PBEN3 */
#define DAI_PBEN16_I_SHIFT      0
#define DAI_PBEN17_I_SHIFT      6
#define DAI_PBEN18_I_SHIFT      12
#define DAI_PBEN19_I_SHIFT      18
#define DAI_PBEN20_I_SHIFT      24


/* -------------------------------------------- */
/*   Bit Field Codes */
/* -------------------------------------------- */
#define F_LOW                   0x00
#define F_HIGH                  0x01
#define F_MISCA0_O              0x02
#define F_MISCA1_O              0x03
#define F_MISCA2_O              0x04
#define F_MISCA3_O              0x05
#define F_MISCA4_O              0x06
#define F_MISCA5_O              0x07
#define F_SPORT0_CLK_PBEN_O     0x08
#define F_SPORT0_FS_PBEN_O      0x09
#define F_SPORT0_DA_PBEN_O      0x0a
#define F_SPORT0_DB_PBEN_O      0x0b
#define F_SPORT1_CLK_PBEN_O     0x0c
#define F_SPORT1_FS_PBEN_O      0x0d
#define F_SPORT1_DA_PBEN_O      0x0e
#define F_SPORT1_DB_PBEN_O      0x0f
#define F_SPORT2_CLK_PBEN_O     0x10
#define F_SPORT2_FS_PBEN_O      0x11
#define F_SPORT2_DA_PBEN_O      0x12
#define F_SPORT2_DB_PBEN_O      0x13
#define F_SPORT3_CLK_PBEN_O     0x14
#define F_SPORT3_FS_PBEN_O      0x15
#define F_SPORT3_DA_PBEN_O      0x16
#define F_SPORT3_DB_PBEN_O      0x17
#define F_SPORT4_CLK_PBEN_O     0x18
#define F_SPORT4_FS_PBEN_O      0x19
#define F_SPORT4_DA_PBEN_O      0x1a
#define F_SPORT4_DB_PBEN_O      0x1b
#define F_SPORT5_CLK_PBEN_O     0x1c
#define F_SPORT5_FS_PBEN_O      0x1d
#define F_SPORT5_DA_PBEN_O      0x1e
#define F_SPORT5_DB_PBEN_O      0x1f
#define F_SPORT6_CLK_PBEN_O     0x20
#define F_SPORT6_FS_PBEN_O      0x21
#define F_SPORT6_DA_PBEN_O      0x22
#define F_SPORT6_DB_PBEN_O      0x23
#define F_SPORT7_CLK_PBEN_O     0x24
#define F_SPORT7_FS_PBEN_O      0x25
#define F_SPORT7_DA_PBEN_O      0x26
#define F_SPORT7_DB_PBEN_O      0x27
#define F_SPORT0_TDV_PBEN_O     0x28
#define F_SPORT1_TDV_PBEN_O     0x29
#define F_SPORT2_TDV_PBEN_O     0x2a
#define F_SPORT3_TDV_PBEN_O     0x2b
#define F_SPORT4_TDV_PBEN_O     0x2c
#define F_SPORT5_TDV_PBEN_O     0x2d
#define F_SPORT6_TDV_PBEN_O     0x2e
#define F_SPORT7_TDV_PBEN_O     0x2f

/*============================================================================*/
/*   Digital Peripheral Interface */
/*   Group A - Signal Assignment */
/*============================================================================*/

/*  GROUP A SRU2 */

#define SPI_MOSI_I_GROUP        GROUP_A2
#define SPI_MISO_I_GROUP        GROUP_A2
#define SPI_DS_I_GROUP          GROUP_A2
#define SPI_CLK_I_GROUP         GROUP_A2
#define SPIB_MOSI_I_GROUP       GROUP_A2
#define SPIB_MISO_I_GROUP       GROUP_A2
#define SPIB_DS_I_GROUP         GROUP_A2
#define SPIB_CLK_I_GROUP        GROUP_A2
#define UART0_RX_I_GROUP        GROUP_A2
#define TWI_DATA_I_GROUP        GROUP_A2
#define TWI_CLK_I_GROUP         GROUP_A2
#define TIMER0_I_GROUP          GROUP_A2
#define TIMER1_I_GROUP          GROUP_A2
#define FLAG4_I_GROUP           GROUP_A2
#define FLAG5_I_GROUP           GROUP_A2
#define FLAG6_I_GROUP           GROUP_A2
#define FLAG7_I_GROUP           GROUP_A2
#define FLAG8_I_GROUP           GROUP_A2
#define FLAG9_I_GROUP           GROUP_A2
#define FLAG10_I_GROUP          GROUP_A2
#define FLAG11_I_GROUP          GROUP_A2
#define FLAG12_I_GROUP          GROUP_A2
#define FLAG13_I_GROUP          GROUP_A2
#define FLAG14_I_GROUP          GROUP_A2
#define FLAG15_I_GROUP          GROUP_A2
#define MISCB0_I_GROUP          GROUP_A2
#define MISCB1_I_GROUP          GROUP_A2
#define MISCB2_I_GROUP          GROUP_A2
#define MISCB3_I_GROUP          GROUP_A2
#define MISCB4_I_GROUP          GROUP_A2
#define MISCB5_I_GROUP          GROUP_A2
#define MISCB6_I_GROUP          GROUP_A2
#define MISCB7_I_GROUP          GROUP_A2
#define MISCB8_I_GROUP          GROUP_A2


/*  SRU2 REGISTER ASSIGNMENTS */

#define SPI_MOSI_I_REG          SRU2_INPUT0
#define SPI_MISO_I_REG          SRU2_INPUT0
#define SPI_DS_I_REG            SRU2_INPUT0
#define SPI_CLK_I_REG           SRU2_INPUT0
#define SPIB_MOSI_I_REG         SRU2_INPUT0
#define SPIB_MISO_I_REG         SRU2_INPUT0

#define SPIB_DS_I_REG           SRU2_INPUT1
#define SPIB_CLK_I_REG          SRU2_INPUT1
#define UART0_RX_I_REG          SRU2_INPUT1
#define TWI_DATA_I_REG          SRU2_INPUT1
#define TWI_CLK_I_REG           SRU2_INPUT1

#define TIMER0_I_REG            SRU2_INPUT2
#define TIMER1_I_REG            SRU2_INPUT2
#define FLAG4_I_REG             SRU2_INPUT2
#define FLAG5_I_REG             SRU2_INPUT2
#define FLAG6_I_REG             SRU2_INPUT2

#define FLAG7_I_REG             SRU2_INPUT3
#define FLAG8_I_REG             SRU2_INPUT3
#define FLAG9_I_REG             SRU2_INPUT3
#define FLAG10_I_REG            SRU2_INPUT3
#define FLAG11_I_REG            SRU2_INPUT3
#define FLAG12_I_REG            SRU2_INPUT3

#define FLAG13_I_REG            SRU2_INPUT4
#define FLAG14_I_REG            SRU2_INPUT4
#define FLAG15_I_REG            SRU2_INPUT4
#define MISCB0_I_REG            SRU2_INPUT4
#define MISCB1_I_REG            SRU2_INPUT4
#define MISCB2_I_REG            SRU2_INPUT4

#define MISCB3_I_REG            SRU2_INPUT5
#define MISCB4_I_REG            SRU2_INPUT5
#define MISCB5_I_REG            SRU2_INPUT5
#define MISCB6_I_REG            SRU2_INPUT5
#define MISCB7_I_REG            SRU2_INPUT5
#define MISCB8_I_REG            SRU2_INPUT5

/* SRU2 SHIFT VALUES FOR BIT FIELDS */

/* SRU2_INPUT0 */
#define SPI_MOSI_I_SHIFT        0
#define SPI_MISO_I_SHIFT        5
#define SPI_DS_I_SHIFT          10
#define SPI_CLK_I_SHIFT         15
#define SPIB_MOSI_I_SHIFT       20
#define SPIB_MISO_I_SHIFT       25

/* SRU2_INPUT1 */
#define SPIB_DS_I_SHIFT         0
#define SPIB_CLK_I_SHIFT        5
#define UART0_RX_I_SHIFT        10
#define TWI_DATA_I_SHIFT        20
#define TWI_CLK_I_SHIFT         25

/* SRU2_INPUT2 */
#define TIMER0_I_SHIFT          0
#define TIMER1_I_SHIFT          5
#define FLAG4_I_SHIFT           15
#define FLAG5_I_SHIFT           20
#define FLAG6_I_SHIFT           25

/* SRU2_INPUT3 */
#define FLAG7_I_SHIFT           0
#define FLAG8_I_SHIFT           5
#define FLAG9_I_SHIFT           10
#define FLAG10_I_SHIFT          15
#define FLAG11_I_SHIFT          20
#define FLAG12_I_SHIFT          25

/* SRU2_INPUT4 */
#define FLAG13_I_SHIFT          0
#define FLAG14_I_SHIFT          5
#define FLAG15_I_SHIFT          10
#define MISCB0_I_SHIFT          15
#define MISCB1_I_SHIFT          20
#define MISCB2_I_SHIFT          25

/* SRU2_INPUT5 */
#define MISCB3_I_SHIFT          0
#define MISCB4_I_SHIFT          5
#define MISCB5_I_SHIFT          10
#define MISCB6_I_SHIFT          15
#define MISCB7_I_SHIFT          20
#define MISCB8_I_SHIFT          25

/* Bit Field Codes For SRU2 */

#define A2_LOW                  0x00
#define A2_HIGH                 0x01
#define A2_DPI_PB01_O           0x02
#define A2_DPI_PB02_O           0x03
#define A2_DPI_PB03_O           0x04
#define A2_DPI_PB04_O           0x05
#define A2_DPI_PB05_O           0x06
#define A2_DPI_PB06_O           0x07
#define A2_DPI_PB07_O           0x08
#define A2_DPI_PB08_O           0x09
#define A2_DPI_PB09_O           0x0a
#define A2_DPI_PB10_O           0x0b
#define A2_DPI_PB11_O           0x0c
#define A2_DPI_PB12_O           0x0d
#define A2_DPI_PB13_O           0x0e
#define A2_DPI_PB14_O           0x0f
#define A2_TIMER0_O             0x10
#define A2_TIMER1_O             0x11

#define A2_UART0_TX_O           0x13


/*============================================================================*/
/*   Digital Peripheral Interface */
/*   Group B - Pin Assignment */
/*============================================================================*/

/*  GROUP B SRU2 */

#define DPI_PB01_I_GROUP        GROUP_B2
#define DPI_PB02_I_GROUP        GROUP_B2
#define DPI_PB03_I_GROUP        GROUP_B2
#define DPI_PB04_I_GROUP        GROUP_B2
#define DPI_PB05_I_GROUP        GROUP_B2
#define DPI_PB06_I_GROUP        GROUP_B2
#define DPI_PB07_I_GROUP        GROUP_B2
#define DPI_PB08_I_GROUP        GROUP_B2
#define DPI_PB09_I_GROUP        GROUP_B2
#define DPI_PB10_I_GROUP        GROUP_B2
#define DPI_PB11_I_GROUP        GROUP_B2
#define DPI_PB12_I_GROUP        GROUP_B2
#define DPI_PB13_I_GROUP        GROUP_B2
#define DPI_PB14_I_GROUP        GROUP_B2

/*  SRU2 REGISTER ASSIGNMENTS */

#define DPI_PB01_I_REG          SRU2_PIN0
#define DPI_PB02_I_REG          SRU2_PIN0
#define DPI_PB03_I_REG          SRU2_PIN0
#define DPI_PB04_I_REG          SRU2_PIN0
#define DPI_PB05_I_REG          SRU2_PIN0

#define DPI_PB06_I_REG          SRU2_PIN1
#define DPI_PB07_I_REG          SRU2_PIN1
#define DPI_PB08_I_REG          SRU2_PIN1
#define DPI_PB09_I_REG          SRU2_PIN1
#define DPI_PB10_I_REG          SRU2_PIN1

#define DPI_PB11_I_REG          SRU2_PIN2
#define DPI_PB12_I_REG          SRU2_PIN2
#define DPI_PB13_I_REG          SRU2_PIN2
#define DPI_PB14_I_REG          SRU2_PIN2

/*  SRU2 Shift Values for Bit Fields */

/*  SRU2_PIN0 */
#define DPI_PB01_I_SHIFT        0
#define DPI_PB02_I_SHIFT        6
#define DPI_PB03_I_SHIFT        12
#define DPI_PB04_I_SHIFT        18
#define DPI_PB05_I_SHIFT        24

/* SRU2_PIN1 */
#define DPI_PB06_I_SHIFT        0
#define DPI_PB07_I_SHIFT        6
#define DPI_PB08_I_SHIFT        12
#define DPI_PB09_I_SHIFT        18
#define DPI_PB10_I_SHIFT        24

/* SRU2_PIN2 */
#define DPI_PB11_I_SHIFT        0
#define DPI_PB12_I_SHIFT        6
#define DPI_PB13_I_SHIFT        12
#define DPI_PB14_I_SHIFT        18

/* SRU2 Bit Fields */
#define B2_LOW                  0x00
#define B2_HIGH                 0x01
#define B2_DPI_PB01_O           0x02
#define B2_DPI_PB02_O           0x03
#define B2_DPI_PB03_O           0x04
#define B2_DPI_PB04_O           0x05
#define B2_DPI_PB05_O           0x06
#define B2_DPI_PB06_O           0x07
#define B2_DPI_PB07_O           0x08
#define B2_DPI_PB08_O           0x09
#define B2_DPI_PB09_O           0x0a
#define B2_DPI_PB10_O           0x0b
#define B2_DPI_PB11_O           0x0c
#define B2_DPI_PB12_O           0x0d
#define B2_DPI_PB13_O           0x0e
#define B2_DPI_PB14_O           0x0f
#define B2_TIMER0_O             0x10
#define B2_TIMER1_O             0x11

#define B2_UART0_TX_O           0x13
#define B2_SPI_MISO_O           0x15
#define B2_SPI_MOSI_O           0x16
#define B2_SPI_CLK_O            0x17
#define B2_SPI_FLG0_O           0x18
#define B2_SPI_FLG1_O           0x19
#define B2_SPI_FLG2_O           0x1a
#define B2_SPI_FLG3_O           0x1b
#define B2_SPIB_MISO_O          0x1c
#define B2_SPIB_MOSI_O          0x1d
#define B2_SPIB_CLK_O           0x1e
#define B2_SPIB_FLG0_O          0x1f
#define B2_SPIB_FLG1_O          0x20
#define B2_SPIB_FLG2_O          0x21
#define B2_SPIB_FLG3_O          0x22
#define B2_FLAG4_O              0x23
#define B2_FLAG5_O              0x24
#define B2_FLAG6_O              0x25
#define B2_FLAG7_O              0x26
#define B2_FLAG8_O              0x27
#define B2_FLAG9_O              0x28
#define B2_FLAG10_O             0x29
#define B2_FLAG11_O             0x2a
#define B2_FLAG12_O             0x2b
#define B2_FLAG13_O             0x2c
#define B2_FLAG14_O             0x2d
#define B2_FLAG15_O             0x2e

#define B2_PWM1_AL_O             0x23
#define B2_PWM1_AH_O             0x24
#define B2_PWM1_BL_O             0x25
#define B2_PWM1_BH_O             0x26
#define B2_PWM2_AL_O             0x27
#define B2_PWM2_AH_O             0x28
#define B2_PWM2_BL_O             0x29
#define B2_PWM2_BH_O             0x2a
#define B2_PWM3_AL_O             0x2b
#define B2_PWM3_AH_O             0x2c
#define B2_PWM3_BL_O             0x2d
#define B2_PWM3_BH_O             0x2e

#define B2_PCG_CLKC_O           0x2f
#define B2_PCG_CLKD_O           0x30
#define B2_PCG_FSC_O            0x31
#define B2_PCG_FSD_O            0x32

/*============================================================================*/
/*   Digital Peripheral Interface */
/*   Group B - Pin Enables */
/*============================================================================*/
/*  SRU2 GROUP C2 */
#define DPI_PBEN01_I_GROUP      GROUP_C2
#define DPI_PBEN02_I_GROUP      GROUP_C2
#define DPI_PBEN03_I_GROUP      GROUP_C2
#define DPI_PBEN04_I_GROUP      GROUP_C2
#define DPI_PBEN05_I_GROUP      GROUP_C2
#define DPI_PBEN06_I_GROUP      GROUP_C2
#define DPI_PBEN07_I_GROUP      GROUP_C2
#define DPI_PBEN08_I_GROUP      GROUP_C2
#define DPI_PBEN09_I_GROUP      GROUP_C2
#define DPI_PBEN10_I_GROUP      GROUP_C2
#define DPI_PBEN11_I_GROUP      GROUP_C2
#define DPI_PBEN12_I_GROUP      GROUP_C2
#define DPI_PBEN13_I_GROUP      GROUP_C2
#define DPI_PBEN14_I_GROUP      GROUP_C2

/* SRU2 Register Assignments */

#define DPI_PBEN01_I_REG      SRU2_PBEN0
#define DPI_PBEN02_I_REG      SRU2_PBEN0
#define DPI_PBEN03_I_REG      SRU2_PBEN0
#define DPI_PBEN04_I_REG      SRU2_PBEN0
#define DPI_PBEN05_I_REG      SRU2_PBEN0

#define DPI_PBEN06_I_REG      SRU2_PBEN1
#define DPI_PBEN07_I_REG      SRU2_PBEN1
#define DPI_PBEN08_I_REG      SRU2_PBEN1
#define DPI_PBEN09_I_REG      SRU2_PBEN1
#define DPI_PBEN10_I_REG      SRU2_PBEN1

#define DPI_PBEN11_I_REG      SRU2_PBEN2
#define DPI_PBEN12_I_REG      SRU2_PBEN2
#define DPI_PBEN13_I_REG      SRU2_PBEN2
#define DPI_PBEN14_I_REG      SRU2_PBEN2

/* SRU2 Shift Values for Bit Fields */

/*  SRU2_PBEN0 */
#define DPI_PBEN01_I_SHIFT      0
#define DPI_PBEN02_I_SHIFT      6
#define DPI_PBEN03_I_SHIFT      12
#define DPI_PBEN04_I_SHIFT      18
#define DPI_PBEN05_I_SHIFT      24

/*  SRU2_PBEN1 */
#define DPI_PBEN06_I_SHIFT      0
#define DPI_PBEN07_I_SHIFT      6
#define DPI_PBEN08_I_SHIFT      12
#define DPI_PBEN09_I_SHIFT      18
#define DPI_PBEN10_I_SHIFT      24

/*  SRU2_PBEN2 */
#define DPI_PBEN11_I_SHIFT      0
#define DPI_PBEN12_I_SHIFT      6
#define DPI_PBEN13_I_SHIFT      12
#define DPI_PBEN14_I_SHIFT      18

/* SRU2 Bit Field Codes */

#define C2_LOW                  0x00
#define C2_HIGH                 0x01
#define C2_MISC0_O              0x02
#define C2_MISC1_O              0x03
#define C2_MISC2_O              0x04

/* New definition to match with docs */
#define C2_MISCB0_O             0x02
#define C2_MISCB1_O             0x03
#define C2_MISCB2_O             0x04
#define C2_TIMER0_PBEN_O        0x05
#define C2_TIMER1_PBEN_O        0x06

#define C2_UART0_TX_PBEN_O      0x08
#define C2_SPI_MISO_PBEN_O      0x0a
#define C2_SPI_MOSI_PBEN_O      0x0b
#define C2_SPI_CLK_PBEN_O       0x0c
#define C2_SPI_FLG0_PBEN_O      0x0d
#define C2_SPI_FLG1_PBEN_O      0x0e
#define C2_SPI_FLG2_PBEN_O      0x0f
#define C2_SPI_FLG3_PBEN_O      0x10
#define C2_SPIB_MISO_PBEN_O     0x11
#define C2_SPIB_MOSI_PBEN_O     0x12
#define C2_SPIB_CLK_PBEN_O      0x13
#define C2_SPIB_FLG0_PBEN_O     0x14
#define C2_SPIB_FLG1_PBEN_O     0x15
#define C2_SPIB_FLG2_PBEN_O     0x16
#define C2_SPIB_FLG3_PBEN_O     0x17
#define C2_FLAG4_PBEN_O         0x18
#define C2_FLAG5_PBEN_O         0x19
#define C2_FLAG6_PBEN_O         0x1a
#define C2_FLAG7_PBEN_O         0x1b
#define C2_FLAG8_PBEN_O         0x1c
#define C2_FLAG9_PBEN_O         0x1d
#define C2_FLAG10_PBEN_O        0x1e
#define C2_FLAG11_PBEN_O        0x1f
#define C2_FLAG12_PBEN_O        0x20
#define C2_FLAG13_PBEN_O        0x21
#define C2_FLAG14_PBEN_O        0x22
#define C2_FLAG15_PBEN_O        0x23

#define C2_PWM1_AL_PBEN_O       0x18
#define C2_PWM1_AH_PBEN_O       0x19
#define C2_PWM1_BL_PBEN_O       0x1a
#define C2_PWM1_BH_PBEN_O       0x1b
#define C2_PWM2_AL_PBEN_O       0x1c
#define C2_PWM2_AH_PBEN_O       0x1d
#define C2_PWM2_BL_PBEN_O       0x1e
#define C2_PWM2_BH_PBEN_O       0x1f
#define C2_PWM3_AL_PBEN_O       0x20
#define C2_PWM3_AH_PBEN_O       0x21
#define C2_PWM3_BL_PBEN_O       0x22
#define C2_PWM3_BH_PBEN_O       0x23

#define C2_TWI_DATA_PBEN_O      0x24
#define C2_TWI_CLK_PBEN_O       0x25
#define C2_MISC3_O              0x26
#define C2_MISC4_O              0x27
#define C2_MISC5_O              0x28
#define C2_MISC6_O              0x29
#define C2_MISC7_O              0x2a
#define C2_MISC8_O              0x2b

/* New definition to match with docs */
#define C2_MISCB3_O              0x26
#define C2_MISCB4_O              0x27
#define C2_MISCB5_O              0x28
#define C2_MISCB6_O              0x29
#define C2_MISCB7_O              0x2a
#define C2_MISCB8_O              0x2b


/*==============================================================================
  Dummy Signals
  The signals listed below don't exist in the given DAI/DPI group but they are
  required by the preprocessor for evaluating the macros sru_fields and
  sru_mask. The code assigned to them them ara arbitrary.
==============================================================================*/

/* DAI SRU Group A dummy signals */


/* SPORT */
#define A_SPORT6_CLK_O          0xFFFFFFFF
#define A_SPORT7_CLK_O          0xFFFFFFFF

#define A_SPORT0_FS_O           0xFFFFFFFF
#define A_SPORT1_FS_O           0xFFFFFFFF
#define A_SPORT2_FS_O           0xFFFFFFFF
#define A_SPORT3_FS_O           0xFFFFFFFF
#define A_SPORT4_FS_O           0xFFFFFFFF
#define A_SPORT5_FS_O           0xFFFFFFFF
#define A_SPORT6_FS_O           0xFFFFFFFF
#define A_SPORT7_FS_O           0xFFFFFFFF

#define A_SPORT0_DA_O           0xFFFFFFFF
#define A_SPORT1_DA_O           0xFFFFFFFF
#define A_SPORT2_DA_O           0xFFFFFFFF
#define A_SPORT3_DA_O           0xFFFFFFFF
#define A_SPORT4_DA_O           0xFFFFFFFF
#define A_SPORT5_DA_O           0xFFFFFFFF
#define A_SPORT6_DA_O           0xFFFFFFFF
#define A_SPORT7_DA_O           0xFFFFFFFF

#define A_SPORT0_DB_O           0xFFFFFFFF
#define A_SPORT1_DB_O           0xFFFFFFFF
#define A_SPORT2_DB_O           0xFFFFFFFF
#define A_SPORT3_DB_O           0xFFFFFFFF
#define A_SPORT4_DB_O           0xFFFFFFFF
#define A_SPORT5_DB_O           0xFFFFFFFF
#define A_SPORT6_DB_O           0xFFFFFFFF
#define A_SPORT7_DB_O           0xFFFFFFFF

#define A_SPORT0_TDV_O          0xFFFFFFFF
#define A_SPORT1_TDV_O          0xFFFFFFFF
#define A_SPORT2_TDV_O          0xFFFFFFFF
#define A_SPORT3_TDV_O          0xFFFFFFFF
#define A_SPORT4_TDV_O          0xFFFFFFFF
#define A_SPORT5_TDV_O          0xFFFFFFFF
#define A_SPORT6_TDV_O          0xFFFFFFFF
#define A_SPORT7_TDV_O          0xFFFFFFFF

#define A_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define A_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define A_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define A_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define A_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define A_SRC0_DAT_OP_O         0xFFFFFFFF
#define A_SRC1_DAT_OP_O         0xFFFFFFFF
#define A_SRC2_DAT_OP_O         0xFFFFFFFF
#define A_SRC3_DAT_OP_O         0xFFFFFFFF
#define A_SRC0_TDM_IP_O         0xFFFFFFFF
#define A_SRC1_TDM_IP_O         0xFFFFFFFF
#define A_SRC2_TDM_IP_O         0xFFFFFFFF
#define A_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define A_PCG_CLKC_O            0xFFFFFFFF
#define A_PCG_CLKD_O            0xFFFFFFFF
#define A_PCG_FSA_O           	0xFFFFFFFF
#define A_PCG_FSB_O           	0xFFFFFFFF
#define A_PCG_FSC_O             0xFFFFFFFF
#define A_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define A_DIR_FS_O           	0xFFFFFFFF
#define A_DIR_DAT_O		        0xFFFFFFFF
#define A_DIR_LRCLK_FB_O        0xFFFFFFFF
#define A_DIR_LRCLK_REF_O       0xFFFFFFFF
#define A_DIT_O			        0xFFFFFFFF
#define A_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define A_MISCA0_O              0xFFFFFFFF
#define A_MISCA1_O              0xFFFFFFFF
#define A_MISCA2_O              0xFFFFFFFF
#define A_MISCA3_O              0xFFFFFFFF
#define A_MISCA4_O              0xFFFFFFFF
#define A_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define A_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define A_DPI_PB01_O            0xFFFFFFFF
#define A_DPI_PB02_O            0xFFFFFFFF
#define A_DPI_PB03_O            0xFFFFFFFF
#define A_DPI_PB04_O            0xFFFFFFFF
#define A_DPI_PB05_O            0xFFFFFFFF
#define A_DPI_PB06_O            0xFFFFFFFF
#define A_DPI_PB07_O            0xFFFFFFFF
#define A_DPI_PB08_O            0xFFFFFFFF
#define A_DPI_PB09_O            0xFFFFFFFF
#define A_DPI_PB10_O            0xFFFFFFFF
#define A_DPI_PB11_O            0xFFFFFFFF
#define A_DPI_PB12_O            0xFFFFFFFF
#define A_DPI_PB13_O            0xFFFFFFFF
#define A_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define A_SPI_MISO_O            0xFFFFFFFF
#define A_SPI_MOSI_O            0xFFFFFFFF
#define A_SPI_CLK_O             0xFFFFFFFF
#define A_SPI_FLG0_O            0xFFFFFFFF
#define A_SPI_FLG1_O            0xFFFFFFFF
#define A_SPI_FLG2_O            0xFFFFFFFF
#define A_SPI_FLG3_O            0xFFFFFFFF

#define A_SPIB_MISO_O           0xFFFFFFFF
#define A_SPIB_MOSI_O           0xFFFFFFFF
#define A_SPIB_CLK_O            0xFFFFFFFF
#define A_SPIB_FLG0_O           0xFFFFFFFF
#define A_SPIB_FLG1_O           0xFFFFFFFF
#define A_SPIB_FLG2_O           0xFFFFFFFF
#define A_SPIB_FLG3_O           0xFFFFFFFF

#define A_SPI_MISO_PBEN_O       0xFFFFFFFF
#define A_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define A_SPI_CLK_PBEN_O        0xFFFFFFFF
#define A_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define A_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define A_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define A_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define A_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define A_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define A_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define A_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define A_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define A_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define A_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define A_FLAG4_O               0xFFFFFFFF
#define A_FLAG5_O               0xFFFFFFFF
#define A_FLAG6_O               0xFFFFFFFF
#define A_FLAG7_O               0xFFFFFFFF
#define A_FLAG8_O               0xFFFFFFFF
#define A_FLAG9_O               0xFFFFFFFF
#define A_FLAG10_O              0xFFFFFFFF
#define A_FLAG11_O              0xFFFFFFFF
#define A_FLAG12_O              0xFFFFFFFF
#define A_FLAG13_O              0xFFFFFFFF
#define A_FLAG14_O              0xFFFFFFFF
#define A_FLAG15_O              0xFFFFFFFF

#define A_PWM1_AL_O             0xFFFFFFFF
#define A_PWM1_AH_O             0xFFFFFFFF
#define A_PWM1_BL_O             0xFFFFFFFF
#define A_PWM1_BH_O             0xFFFFFFFF
#define A_PWM2_AL_O             0xFFFFFFFF
#define A_PWM2_AH_O             0xFFFFFFFF
#define A_PWM2_BL_O             0xFFFFFFFF
#define A_PWM2_BH_O             0xFFFFFFFF
#define A_PWM3_AL_O             0xFFFFFFFF
#define A_PWM3_AH_O             0xFFFFFFFF
#define A_PWM3_BL_O             0xFFFFFFFF
#define A_PWM3_BH_O

#define A_FLAG4_PBEN_O         0xFFFFFFFF
#define A_FLAG5_PBEN_O         0xFFFFFFFF
#define A_FLAG6_PBEN_O         0xFFFFFFFF
#define A_FLAG7_PBEN_O         0xFFFFFFFF
#define A_FLAG8_PBEN_O         0xFFFFFFFF
#define A_FLAG9_PBEN_O         0xFFFFFFFF
#define A_FLAG10_PBEN_O         0xFFFFFFFF
#define A_FLAG11_PBEN_O         0xFFFFFFFF
#define A_FLAG12_PBEN_O         0xFFFFFFFF
#define A_FLAG13_PBEN_O         0xFFFFFFFF
#define A_FLAG14_PBEN_O         0xFFFFFFFF
#define A_FLAG15_PBEN_O         0xFFFFFFFF

#define A_PWM1_AL_PBEN_O             0xFFFFFFFF
#define A_PWM1_AH_PBEN_O             0xFFFFFFFF
#define A_PWM1_BL_PBEN_O             0xFFFFFFFF
#define A_PWM1_BH_PBEN_O             0xFFFFFFFF
#define A_PWM2_AL_PBEN_O             0xFFFFFFFF
#define A_PWM2_AH_PBEN_O             0xFFFFFFFF
#define A_PWM2_BL_PBEN_O             0xFFFFFFFF
#define A_PWM2_BH_PBEN_O             0xFFFFFFFF
#define A_PWM3_AL_PBEN_O             0xFFFFFFFF
#define A_PWM3_AH_PBEN_O             0xFFFFFFFF
#define A_PWM3_BL_PBEN_O             0xFFFFFFFF
#define A_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define A_MISCB0_O               0xFFFFFFFF
#define A_MISCB1_O               0xFFFFFFFF
#define A_MISCB2_O               0xFFFFFFFF
#define A_MISCB3_O               0xFFFFFFFF
#define A_MISCB4_O               0xFFFFFFFF
#define A_MISCB5_O               0xFFFFFFFF
#define A_MISCB6_O               0xFFFFFFFF
#define A_MISCB7_O               0xFFFFFFFF
#define A_MISCB8_O               0xFFFFFFFF
#define A_MISC0_O                0xFFFFFFFF
#define A_MISC1_O                0xFFFFFFFF
#define A_MISC2_O                0xFFFFFFFF
#define A_MISC3_O                0xFFFFFFFF
#define A_MISC4_O                0xFFFFFFFF
#define A_MISC5_O                0xFFFFFFFF
#define A_MISC6_O                0xFFFFFFFF
#define A_MISC7_O                0xFFFFFFFF
#define A_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define A_TIMER0_O              0xFFFFFFFF
#define A_TIMER1_O              0xFFFFFFFF
#define A_TIMER0_PBEN_O         0xFFFFFFFF
#define A_TIMER1_PBEN_O         0xFFFFFFFF

/* UART  */
#define A_UART0_TX_O            0xFFFFFFFF
#define A_UART0_TX_PBEN_O       0xFFFFFFFF

/*  TWI  */
#define A_TWI_DATA_PBEN_O       0xFFFFFFFF
#define A_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  A_SR_LAT_O              0xffffffff
#define  A_SR_SCLK_O             0xffffffff
#define  A_SR_SDAT_O             0xffffffff




/* DAI SRU Group B dummy signals */

/* SPORT */
#define B_SPORT0_CLK_O          0xFFFFFFFF
#define B_SPORT1_CLK_O          0xFFFFFFFF
#define B_SPORT2_CLK_O          0xFFFFFFFF
#define B_SPORT3_CLK_O          0xFFFFFFFF
#define B_SPORT4_CLK_O          0xFFFFFFFF
#define B_SPORT5_CLK_O          0xFFFFFFFF
#define B_SPORT6_CLK_O          0xFFFFFFFF
#define B_SPORT7_CLK_O          0xFFFFFFFF

#define B_SPORT0_FS_O           0xFFFFFFFF
#define B_SPORT1_FS_O           0xFFFFFFFF
#define B_SPORT2_FS_O           0xFFFFFFFF
#define B_SPORT3_FS_O           0xFFFFFFFF
#define B_SPORT4_FS_O           0xFFFFFFFF
#define B_SPORT5_FS_O           0xFFFFFFFF
#define B_SPORT6_FS_O           0xFFFFFFFF
#define B_SPORT7_FS_O           0xFFFFFFFF

#define B_SPORT0_TDV_O          0xFFFFFFFF
#define B_SPORT1_TDV_O          0xFFFFFFFF
#define B_SPORT2_TDV_O          0xFFFFFFFF
#define B_SPORT3_TDV_O          0xFFFFFFFF
#define B_SPORT4_TDV_O          0xFFFFFFFF
#define B_SPORT5_TDV_O          0xFFFFFFFF
#define B_SPORT6_TDV_O          0xFFFFFFFF
#define B_SPORT7_TDV_O          0xFFFFFFFF

#define B_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define B_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define B_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define B_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define B_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/

/* PCG 	*/
#define	B_PCG_CLKA_O			0xFFFFFFFF
#define	B_PCG_CLKB_O			0xFFFFFFFF
#define B_PCG_CLKC_O            0xFFFFFFFF
#define B_PCG_CLKD_O            0xFFFFFFFF
#define B_PCG_FSA_O           	0xFFFFFFFF
#define B_PCG_FSB_O           	0xFFFFFFFF
#define B_PCG_FSC_O             0xFFFFFFFF
#define B_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	B_DIR_CLK_O				0xFFFFFFFF
#define	B_DIR_TDMCLK_O			0xFFFFFFFF
#define B_DIR_FS_O           	0xFFFFFFFF
#define B_DIR_LRCLK_FB_O        0xFFFFFFFF
#define B_DIR_LRCLK_REF_O       0xFFFFFFFF
#define B_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define B_MISCA0_O              0xFFFFFFFF
#define B_MISCA1_O              0xFFFFFFFF
#define B_MISCA2_O              0xFFFFFFFF
#define B_MISCA3_O              0xFFFFFFFF
#define B_MISCA4_O              0xFFFFFFFF
#define B_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define B_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define B_DPI_PB01_O            0xFFFFFFFF
#define B_DPI_PB02_O            0xFFFFFFFF
#define B_DPI_PB03_O            0xFFFFFFFF
#define B_DPI_PB04_O            0xFFFFFFFF
#define B_DPI_PB05_O            0xFFFFFFFF
#define B_DPI_PB06_O            0xFFFFFFFF
#define B_DPI_PB07_O            0xFFFFFFFF
#define B_DPI_PB08_O            0xFFFFFFFF
#define B_DPI_PB09_O            0xFFFFFFFF
#define B_DPI_PB10_O            0xFFFFFFFF
#define B_DPI_PB11_O            0xFFFFFFFF
#define B_DPI_PB12_O            0xFFFFFFFF
#define B_DPI_PB13_O            0xFFFFFFFF
#define B_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define B_SPI_MISO_O            0xFFFFFFFF
#define B_SPI_MOSI_O            0xFFFFFFFF
#define B_SPI_CLK_O             0xFFFFFFFF
#define B_SPI_FLG0_O            0xFFFFFFFF
#define B_SPI_FLG1_O            0xFFFFFFFF
#define B_SPI_FLG2_O            0xFFFFFFFF
#define B_SPI_FLG3_O            0xFFFFFFFF

#define B_SPIB_MISO_O           0xFFFFFFFF
#define B_SPIB_MOSI_O           0xFFFFFFFF
#define B_SPIB_CLK_O            0xFFFFFFFF
#define B_SPIB_FLG0_O           0xFFFFFFFF
#define B_SPIB_FLG1_O           0xFFFFFFFF
#define B_SPIB_FLG2_O           0xFFFFFFFF
#define B_SPIB_FLG3_O           0xFFFFFFFF

#define B_SPI_MISO_PBEN_O       0xFFFFFFFF
#define B_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define B_SPI_CLK_PBEN_O        0xFFFFFFFF
#define B_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define B_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define B_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define B_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define B_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define B_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define B_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define B_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define B_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define B_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define B_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define B_FLAG4_O               0xFFFFFFFF
#define B_FLAG5_O               0xFFFFFFFF
#define B_FLAG6_O               0xFFFFFFFF
#define B_FLAG7_O               0xFFFFFFFF
#define B_FLAG8_O               0xFFFFFFFF
#define B_FLAG9_O               0xFFFFFFFF
#define B_FLAG10_O              0xFFFFFFFF
#define B_FLAG11_O              0xFFFFFFFF
#define B_FLAG12_O              0xFFFFFFFF
#define B_FLAG13_O              0xFFFFFFFF
#define B_FLAG14_O              0xFFFFFFFF
#define B_FLAG15_O              0xFFFFFFFF

#define B_PWM1_AL_O             0xFFFFFFFF
#define B_PWM1_AH_O             0xFFFFFFFF
#define B_PWM1_BL_O             0xFFFFFFFF
#define B_PWM1_BH_O             0xFFFFFFFF
#define B_PWM2_AL_O             0xFFFFFFFF
#define B_PWM2_AH_O             0xFFFFFFFF
#define B_PWM2_BL_O             0xFFFFFFFF
#define B_PWM2_BH_O             0xFFFFFFFF
#define B_PWM3_AL_O             0xFFFFFFFF
#define B_PWM3_AH_O             0xFFFFFFFF
#define B_PWM3_BL_O             0xFFFFFFFF
#define B_PWM3_BH_O             0xFFFFFFFF

#define B_FLAG4_PBEN_O         0xFFFFFFFF
#define B_FLAG5_PBEN_O         0xFFFFFFFF
#define B_FLAG6_PBEN_O         0xFFFFFFFF
#define B_FLAG7_PBEN_O         0xFFFFFFFF
#define B_FLAG8_PBEN_O         0xFFFFFFFF
#define B_FLAG9_PBEN_O         0xFFFFFFFF
#define B_FLAG10_PBEN_O         0xFFFFFFFF
#define B_FLAG11_PBEN_O         0xFFFFFFFF
#define B_FLAG12_PBEN_O         0xFFFFFFFF
#define B_FLAG13_PBEN_O         0xFFFFFFFF
#define B_FLAG14_PBEN_O         0xFFFFFFFF
#define B_FLAG15_PBEN_O         0xFFFFFFFF

#define B_PWM1_AL_PBEN_O             0xFFFFFFFF
#define B_PWM1_AH_PBEN_O             0xFFFFFFFF
#define B_PWM1_BL_PBEN_O             0xFFFFFFFF
#define B_PWM1_BH_PBEN_O             0xFFFFFFFF
#define B_PWM2_AL_PBEN_O             0xFFFFFFFF
#define B_PWM2_AH_PBEN_O             0xFFFFFFFF
#define B_PWM2_BL_PBEN_O             0xFFFFFFFF
#define B_PWM2_BH_PBEN_O             0xFFFFFFFF
#define B_PWM3_AL_PBEN_O             0xFFFFFFFF
#define B_PWM3_AH_PBEN_O             0xFFFFFFFF
#define B_PWM3_BL_PBEN_O             0xFFFFFFFF
#define B_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define B_MISCB0_O               0xFFFFFFFF
#define B_MISCB1_O               0xFFFFFFFF
#define B_MISCB2_O               0xFFFFFFFF
#define B_MISCB3_O               0xFFFFFFFF
#define B_MISCB4_O               0xFFFFFFFF
#define B_MISCB5_O               0xFFFFFFFF
#define B_MISCB6_O               0xFFFFFFFF
#define B_MISCB7_O               0xFFFFFFFF
#define B_MISCB8_O               0xFFFFFFFF
#define B_MISC0_O                0xFFFFFFFF
#define B_MISC1_O                0xFFFFFFFF
#define B_MISC2_O                0xFFFFFFFF
#define B_MISC3_O                0xFFFFFFFF
#define B_MISC4_O                0xFFFFFFFF
#define B_MISC5_O                0xFFFFFFFF
#define B_MISC6_O                0xFFFFFFFF
#define B_MISC7_O                0xFFFFFFFF
#define B_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define B_TIMER0_O              0xFFFFFFFF
#define B_TIMER1_O              0xFFFFFFFF

#define B_TIMER0_PBEN_O         0xFFFFFFFF
#define B_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define B_UART0_TX_O            0xFFFFFFFF


#define B_UART0_TX_PBEN_O       0xFFFFFFFF


/*  TWI  */
#define B_TWI_DATA_PBEN_O       0xFFFFFFFF
#define B_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  B_SR_LAT_O              0xffffffff
#define  B_SR_SCLK_O             0xffffffff
#define  B_SR_SDAT_O             0xffffffff



/* DAI SRU Group C dummy signals */

/* SPORT */
#define C_SPORT0_CLK_O          0xFFFFFFFF
#define C_SPORT1_CLK_O          0xFFFFFFFF
#define C_SPORT2_CLK_O          0xFFFFFFFF
#define C_SPORT3_CLK_O          0xFFFFFFFF
#define C_SPORT4_CLK_O          0xFFFFFFFF
#define C_SPORT5_CLK_O          0xFFFFFFFF
#define C_SPORT6_CLK_O          0xFFFFFFFF
#define C_SPORT7_CLK_O          0xFFFFFFFF

#define C_SPORT6_FS_O          0xFFFFFFFF
#define C_SPORT7_FS_O          0xFFFFFFFF

#define C_SPORT0_DA_O           0xFFFFFFFF
#define C_SPORT1_DA_O           0xFFFFFFFF
#define C_SPORT2_DA_O           0xFFFFFFFF
#define C_SPORT3_DA_O           0xFFFFFFFF
#define C_SPORT4_DA_O           0xFFFFFFFF
#define C_SPORT5_DA_O           0xFFFFFFFF
#define C_SPORT6_DA_O           0xFFFFFFFF
#define C_SPORT7_DA_O           0xFFFFFFFF

#define C_SPORT0_DB_O           0xFFFFFFFF
#define C_SPORT1_DB_O           0xFFFFFFFF
#define C_SPORT2_DB_O           0xFFFFFFFF
#define C_SPORT3_DB_O           0xFFFFFFFF
#define C_SPORT4_DB_O           0xFFFFFFFF
#define C_SPORT5_DB_O           0xFFFFFFFF
#define C_SPORT6_DB_O           0xFFFFFFFF
#define C_SPORT7_DB_O           0xFFFFFFFF

#define C_SPORT0_TDV_O          0xFFFFFFFF
#define C_SPORT1_TDV_O          0xFFFFFFFF
#define C_SPORT2_TDV_O          0xFFFFFFFF
#define C_SPORT3_TDV_O          0xFFFFFFFF
#define C_SPORT4_TDV_O          0xFFFFFFFF
#define C_SPORT5_TDV_O          0xFFFFFFFF
#define C_SPORT6_TDV_O          0xFFFFFFFF
#define C_SPORT7_TDV_O          0xFFFFFFFF

#define C_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define C_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define C_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define C_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define C_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define C_SRC0_DAT_OP_O         0xFFFFFFFF
#define C_SRC1_DAT_OP_O         0xFFFFFFFF
#define C_SRC2_DAT_OP_O         0xFFFFFFFF
#define C_SRC3_DAT_OP_O         0xFFFFFFFF
#define C_SRC0_TDM_IP_O         0xFFFFFFFF
#define C_SRC1_TDM_IP_O         0xFFFFFFFF
#define C_SRC2_TDM_IP_O         0xFFFFFFFF
#define C_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	C_PCG_CLKA_O			0xFFFFFFFF
#define	C_PCG_CLKB_O			0xFFFFFFFF
#define C_PCG_CLKC_O            0xFFFFFFFF
#define C_PCG_CLKD_O            0xFFFFFFFF
#define C_PCG_FSC_O             0xFFFFFFFF
#define C_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	C_DIR_CLK_O				0xFFFFFFFF
#define	C_DIR_TDMCLK_O			0xFFFFFFFF
#define C_DIR_DAT_O		        0xFFFFFFFF
#define C_DIR_LRCLK_FB_O        0xFFFFFFFF
#define C_DIR_LRCLK_REF_O       0xFFFFFFFF
#define C_DIT_O			        0xFFFFFFFF
#define C_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define C_MISCA0_O              0xFFFFFFFF
#define C_MISCA1_O              0xFFFFFFFF
#define C_MISCA2_O              0xFFFFFFFF
#define C_MISCA3_O              0xFFFFFFFF
#define C_MISCA4_O              0xFFFFFFFF
#define C_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define C_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define C_DPI_PB01_O            0xFFFFFFFF
#define C_DPI_PB02_O            0xFFFFFFFF
#define C_DPI_PB03_O            0xFFFFFFFF
#define C_DPI_PB04_O            0xFFFFFFFF
#define C_DPI_PB05_O            0xFFFFFFFF
#define C_DPI_PB06_O            0xFFFFFFFF
#define C_DPI_PB07_O            0xFFFFFFFF
#define C_DPI_PB08_O            0xFFFFFFFF
#define C_DPI_PB09_O            0xFFFFFFFF
#define C_DPI_PB10_O            0xFFFFFFFF
#define C_DPI_PB11_O            0xFFFFFFFF
#define C_DPI_PB12_O            0xFFFFFFFF
#define C_DPI_PB13_O            0xFFFFFFFF
#define C_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define C_SPI_MISO_O            0xFFFFFFFF
#define C_SPI_MOSI_O            0xFFFFFFFF
#define C_SPI_CLK_O             0xFFFFFFFF
#define C_SPI_FLG0_O            0xFFFFFFFF
#define C_SPI_FLG1_O            0xFFFFFFFF
#define C_SPI_FLG2_O            0xFFFFFFFF
#define C_SPI_FLG3_O            0xFFFFFFFF

#define C_SPIB_MISO_O           0xFFFFFFFF
#define C_SPIB_MOSI_O           0xFFFFFFFF
#define C_SPIB_CLK_O            0xFFFFFFFF
#define C_SPIB_FLG0_O           0xFFFFFFFF
#define C_SPIB_FLG1_O           0xFFFFFFFF
#define C_SPIB_FLG2_O           0xFFFFFFFF
#define C_SPIB_FLG3_O           0xFFFFFFFF

#define C_SPI_MISO_PBEN_O       0xFFFFFFFF
#define C_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define C_SPI_CLK_PBEN_O        0xFFFFFFFF
#define C_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define C_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define C_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define C_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define C_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define C_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define C_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define C_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define C_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define C_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define C_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define C_FLAG4_O               0xFFFFFFFF
#define C_FLAG5_O               0xFFFFFFFF
#define C_FLAG6_O               0xFFFFFFFF
#define C_FLAG7_O               0xFFFFFFFF
#define C_FLAG8_O               0xFFFFFFFF
#define C_FLAG9_O               0xFFFFFFFF
#define C_FLAG10_O              0xFFFFFFFF
#define C_FLAG11_O              0xFFFFFFFF
#define C_FLAG12_O              0xFFFFFFFF
#define C_FLAG13_O              0xFFFFFFFF
#define C_FLAG14_O              0xFFFFFFFF
#define C_FLAG15_O              0xFFFFFFFF

#define C_PWM1_AL_O             0xFFFFFFFF
#define C_PWM1_AH_O             0xFFFFFFFF
#define C_PWM1_BL_O             0xFFFFFFFF
#define C_PWM1_BH_O             0xFFFFFFFF
#define C_PWM2_AL_O             0xFFFFFFFF
#define C_PWM2_AH_O             0xFFFFFFFF
#define C_PWM2_BL_O             0xFFFFFFFF
#define C_PWM2_BH_O             0xFFFFFFFF
#define C_PWM3_AL_O             0xFFFFFFFF
#define C_PWM3_AH_O             0xFFFFFFFF
#define C_PWM3_BL_O             0xFFFFFFFF
#define C_PWM3_BH_O             0xFFFFFFFF

#define C_FLAG4_PBEN_O         0xFFFFFFFF
#define C_FLAG5_PBEN_O         0xFFFFFFFF
#define C_FLAG6_PBEN_O         0xFFFFFFFF
#define C_FLAG7_PBEN_O         0xFFFFFFFF
#define C_FLAG8_PBEN_O         0xFFFFFFFF
#define C_FLAG9_PBEN_O         0xFFFFFFFF
#define C_FLAG10_PBEN_O         0xFFFFFFFF
#define C_FLAG11_PBEN_O         0xFFFFFFFF
#define C_FLAG12_PBEN_O         0xFFFFFFFF
#define C_FLAG13_PBEN_O         0xFFFFFFFF
#define C_FLAG14_PBEN_O         0xFFFFFFFF
#define C_FLAG15_PBEN_O         0xFFFFFFFF

#define C_PWM1_AL_PBEN_O             0xFFFFFFFF
#define C_PWM1_AH_PBEN_O             0xFFFFFFFF
#define C_PWM1_BL_PBEN_O             0xFFFFFFFF
#define C_PWM1_BH_PBEN_O             0xFFFFFFFF
#define C_PWM2_AL_PBEN_O             0xFFFFFFFF
#define C_PWM2_AH_PBEN_O             0xFFFFFFFF
#define C_PWM2_BL_PBEN_O             0xFFFFFFFF
#define C_PWM2_BH_PBEN_O             0xFFFFFFFF
#define C_PWM3_AL_PBEN_O             0xFFFFFFFF
#define C_PWM3_AH_PBEN_O             0xFFFFFFFF
#define C_PWM3_BL_PBEN_O             0xFFFFFFFF
#define C_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define C_MISCB0_O               0xFFFFFFFF
#define C_MISCB1_O               0xFFFFFFFF
#define C_MISCB2_O               0xFFFFFFFF
#define C_MISCB3_O               0xFFFFFFFF
#define C_MISCB4_O               0xFFFFFFFF
#define C_MISCB5_O               0xFFFFFFFF
#define C_MISCB6_O               0xFFFFFFFF
#define C_MISCB7_O               0xFFFFFFFF
#define C_MISCB8_O               0xFFFFFFFF
#define C_MISC0_O                0xFFFFFFFF
#define C_MISC1_O                0xFFFFFFFF
#define C_MISC2_O                0xFFFFFFFF
#define C_MISC3_O                0xFFFFFFFF
#define C_MISC4_O                0xFFFFFFFF
#define C_MISC5_O                0xFFFFFFFF
#define C_MISC6_O                0xFFFFFFFF
#define C_MISC7_O                0xFFFFFFFF
#define C_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define C_TIMER0_O              0xFFFFFFFF
#define C_TIMER1_O              0xFFFFFFFF
#define C_TIMER0_PBEN_O         0xFFFFFFFF
#define C_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define C_UART0_TX_O            0xFFFFFFFF
#define C_UART0_TX_PBEN_O       0xFFFFFFFF


/*  TWI  */
#define C_TWI_DATA_PBEN_O       0xFFFFFFFF
#define C_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  C_SR_LAT_O              0xffffffff
#define  C_SR_SCLK_O             0xffffffff
#define  C_SR_SDAT_O             0xffffffff




/* DAI SRU Group D dummy signals */

/* SPORT */

#define D_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define D_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define D_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define D_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define D_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define D_SRC0_TDM_IP_O         0xFFFFFFFF
#define D_SRC1_TDM_IP_O         0xFFFFFFFF
#define D_SRC2_TDM_IP_O         0xFFFFFFFF
#define D_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/

/* 	S/PDIF  */

/* MISCA	*/
#define D_MISCA0_O              0xFFFFFFFF
#define D_MISCA1_O              0xFFFFFFFF
#define D_MISCA2_O              0xFFFFFFFF
#define D_MISCA3_O              0xFFFFFFFF
#define D_MISCA4_O              0xFFFFFFFF
#define D_MISCA5_O              0xFFFFFFFF

/* PDAP	*/

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define D_DPI_PB01_O            0xFFFFFFFF
#define D_DPI_PB02_O            0xFFFFFFFF
#define D_DPI_PB03_O            0xFFFFFFFF
#define D_DPI_PB04_O            0xFFFFFFFF
#define D_DPI_PB05_O            0xFFFFFFFF
#define D_DPI_PB06_O            0xFFFFFFFF
#define D_DPI_PB07_O            0xFFFFFFFF
#define D_DPI_PB08_O            0xFFFFFFFF
#define D_DPI_PB09_O            0xFFFFFFFF
#define D_DPI_PB10_O            0xFFFFFFFF
#define D_DPI_PB11_O            0xFFFFFFFF
#define D_DPI_PB12_O            0xFFFFFFFF
#define D_DPI_PB13_O            0xFFFFFFFF
#define D_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define D_SPI_MISO_O            0xFFFFFFFF
#define D_SPI_MOSI_O            0xFFFFFFFF
#define D_SPI_CLK_O             0xFFFFFFFF
#define D_SPI_FLG0_O            0xFFFFFFFF
#define D_SPI_FLG1_O            0xFFFFFFFF
#define D_SPI_FLG2_O            0xFFFFFFFF
#define D_SPI_FLG3_O            0xFFFFFFFF

#define D_SPIB_MISO_O           0xFFFFFFFF
#define D_SPIB_MOSI_O           0xFFFFFFFF
#define D_SPIB_CLK_O            0xFFFFFFFF
#define D_SPIB_FLG0_O           0xFFFFFFFF
#define D_SPIB_FLG1_O           0xFFFFFFFF
#define D_SPIB_FLG2_O           0xFFFFFFFF
#define D_SPIB_FLG3_O           0xFFFFFFFF

#define D_SPI_MISO_PBEN_O       0xFFFFFFFF
#define D_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define D_SPI_CLK_PBEN_O        0xFFFFFFFF
#define D_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define D_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define D_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define D_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define D_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define D_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define D_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define D_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define D_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define D_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define D_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define D_FLAG4_O               0xFFFFFFFF
#define D_FLAG5_O               0xFFFFFFFF
#define D_FLAG6_O               0xFFFFFFFF
#define D_FLAG7_O               0xFFFFFFFF
#define D_FLAG8_O               0xFFFFFFFF
#define D_FLAG9_O               0xFFFFFFFF
#define D_FLAG10_O              0xFFFFFFFF
#define D_FLAG11_O              0xFFFFFFFF
#define D_FLAG12_O              0xFFFFFFFF
#define D_FLAG13_O              0xFFFFFFFF
#define D_FLAG14_O              0xFFFFFFFF
#define D_FLAG15_O              0xFFFFFFFF

#define D_PWM1_AL_O             0xFFFFFFFF
#define D_PWM1_AH_O             0xFFFFFFFF
#define D_PWM1_BL_O             0xFFFFFFFF
#define D_PWM1_BH_O             0xFFFFFFFF
#define D_PWM2_AL_O             0xFFFFFFFF
#define D_PWM2_AH_O             0xFFFFFFFF
#define D_PWM2_BL_O             0xFFFFFFFF
#define D_PWM2_BH_O             0xFFFFFFFF
#define D_PWM3_AL_O             0xFFFFFFFF
#define D_PWM3_AH_O             0xFFFFFFFF
#define D_PWM3_BL_O             0xFFFFFFFF
#define D_PWM3_BH_O             0xFFFFFFFF

#define D_FLAG4_PBEN_O         0xFFFFFFFF
#define D_FLAG5_PBEN_O         0xFFFFFFFF
#define D_FLAG6_PBEN_O         0xFFFFFFFF
#define D_FLAG7_PBEN_O         0xFFFFFFFF
#define D_FLAG8_PBEN_O         0xFFFFFFFF
#define D_FLAG9_PBEN_O         0xFFFFFFFF
#define D_FLAG10_PBEN_O         0xFFFFFFFF
#define D_FLAG11_PBEN_O         0xFFFFFFFF
#define D_FLAG12_PBEN_O         0xFFFFFFFF
#define D_FLAG13_PBEN_O         0xFFFFFFFF
#define D_FLAG14_PBEN_O         0xFFFFFFFF
#define D_FLAG15_PBEN_O         0xFFFFFFFF

#define D_PWM1_AL_PBEN_O             0xFFFFFFFF
#define D_PWM1_AH_PBEN_O             0xFFFFFFFF
#define D_PWM1_BL_PBEN_O             0xFFFFFFFF
#define D_PWM1_BH_PBEN_O             0xFFFFFFFF
#define D_PWM2_AL_PBEN_O             0xFFFFFFFF
#define D_PWM2_AH_PBEN_O             0xFFFFFFFF
#define D_PWM2_BL_PBEN_O             0xFFFFFFFF
#define D_PWM2_BH_PBEN_O             0xFFFFFFFF
#define D_PWM3_AL_PBEN_O             0xFFFFFFFF
#define D_PWM3_AH_PBEN_O             0xFFFFFFFF
#define D_PWM3_BL_PBEN_O             0xFFFFFFFF
#define D_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define D_MISCB0_O               0xFFFFFFFF
#define D_MISCB1_O               0xFFFFFFFF
#define D_MISCB2_O               0xFFFFFFFF
#define D_MISCB3_O               0xFFFFFFFF
#define D_MISCB4_O               0xFFFFFFFF
#define D_MISCB5_O               0xFFFFFFFF
#define D_MISCB6_O               0xFFFFFFFF
#define D_MISCB7_O               0xFFFFFFFF
#define D_MISCB8_O               0xFFFFFFFF
#define D_MISC0_O                0xFFFFFFFF
#define D_MISC1_O                0xFFFFFFFF
#define D_MISC2_O                0xFFFFFFFF
#define D_MISC3_O                0xFFFFFFFF
#define D_MISC4_O                0xFFFFFFFF
#define D_MISC5_O                0xFFFFFFFF
#define D_MISC6_O                0xFFFFFFFF
#define D_MISC7_O                0xFFFFFFFF
#define D_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define D_TIMER0_O              0xFFFFFFFF
#define D_TIMER1_O              0xFFFFFFFF
#define D_TIMER0_PBEN_O         0xFFFFFFFF
#define D_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define D_UART0_TX_O            0xFFFFFFFF
#define D_UART0_TX_PBEN_O       0xFFFFFFFF


/*  TWI  */
#define D_TWI_DATA_PBEN_O       0xFFFFFFFF
#define D_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  D_SR_LAT_O              0xffffffff
#define  D_SR_SCLK_O             0xffffffff
#define  D_SR_SDAT_O             0xffffffff


/* DAI SRU Group E dummy signals */

/* SPORT */
#define E_SPORT0_CLK_O          0xFFFFFFFF
#define E_SPORT1_CLK_O          0xFFFFFFFF
#define E_SPORT2_CLK_O          0xFFFFFFFF
#define E_SPORT3_CLK_O          0xFFFFFFFF
#define E_SPORT4_CLK_O          0xFFFFFFFF
#define E_SPORT5_CLK_O          0xFFFFFFFF
#define E_SPORT6_CLK_O          0xFFFFFFFF
#define E_SPORT7_CLK_O          0xFFFFFFFF

#define E_SPORT6_FS_O          0xFFFFFFFF
#define E_SPORT7_FS_O          0xFFFFFFFF


#define E_SPORT0_DA_O           0xFFFFFFFF
#define E_SPORT1_DA_O           0xFFFFFFFF
#define E_SPORT2_DA_O           0xFFFFFFFF
#define E_SPORT3_DA_O           0xFFFFFFFF
#define E_SPORT4_DA_O           0xFFFFFFFF
#define E_SPORT5_DA_O           0xFFFFFFFF
#define E_SPORT6_DA_O           0xFFFFFFFF
#define E_SPORT7_DA_O           0xFFFFFFFF

#define E_SPORT0_DB_O           0xFFFFFFFF
#define E_SPORT1_DB_O           0xFFFFFFFF
#define E_SPORT2_DB_O           0xFFFFFFFF
#define E_SPORT3_DB_O           0xFFFFFFFF
#define E_SPORT4_DB_O           0xFFFFFFFF
#define E_SPORT5_DB_O           0xFFFFFFFF
#define E_SPORT6_DB_O           0xFFFFFFFF
#define E_SPORT7_DB_O           0xFFFFFFFF

#define E_SPORT0_TDV_O          0xFFFFFFFF
#define E_SPORT1_TDV_O          0xFFFFFFFF
#define E_SPORT2_TDV_O          0xFFFFFFFF
#define E_SPORT3_TDV_O          0xFFFFFFFF
#define E_SPORT4_TDV_O          0xFFFFFFFF
#define E_SPORT5_TDV_O          0xFFFFFFFF
#define E_SPORT6_TDV_O          0xFFFFFFFF
#define E_SPORT7_TDV_O          0xFFFFFFFF

#define E_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define E_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define E_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define E_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define E_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define E_SRC0_DAT_OP_O         0xFFFFFFFF
#define E_SRC1_DAT_OP_O         0xFFFFFFFF
#define E_SRC2_DAT_OP_O         0xFFFFFFFF
#define E_SRC3_DAT_OP_O         0xFFFFFFFF
#define E_SRC0_TDM_IP_O         0xFFFFFFFF
#define E_SRC1_TDM_IP_O         0xFFFFFFFF
#define E_SRC2_TDM_IP_O         0xFFFFFFFF
#define E_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	E_PCG_CLKA_O			0xFFFFFFFF
#define E_PCG_CLKC_O            0xFFFFFFFF
#define E_PCG_CLKD_O            0xFFFFFFFF
#define E_PCG_FSC_O             0xFFFFFFFF
#define E_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	E_DIR_CLK_O				0xFFFFFFFF
#define	E_DIR_TDMCLK_O			0xFFFFFFFF
#define E_DIR_FS_O           	0xFFFFFFFF
#define E_DIR_DAT_O		        0xFFFFFFFF
#define E_DIR_LRCLK_FB_O        0xFFFFFFFF
#define E_DIR_LRCLK_REF_O       0xFFFFFFFF
#define E_DIT_O			        0xFFFFFFFF

/* MISCA	*/
#define E_MISCA0_O              0xFFFFFFFF
#define E_MISCA1_O              0xFFFFFFFF
#define E_MISCA2_O              0xFFFFFFFF
#define E_MISCA3_O              0xFFFFFFFF
#define E_MISCA4_O              0xFFFFFFFF
#define E_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define E_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define E_DPI_PB01_O            0xFFFFFFFF
#define E_DPI_PB02_O            0xFFFFFFFF
#define E_DPI_PB03_O            0xFFFFFFFF
#define E_DPI_PB04_O            0xFFFFFFFF
#define E_DPI_PB05_O            0xFFFFFFFF
#define E_DPI_PB06_O            0xFFFFFFFF
#define E_DPI_PB07_O            0xFFFFFFFF
#define E_DPI_PB08_O            0xFFFFFFFF
#define E_DPI_PB09_O            0xFFFFFFFF
#define E_DPI_PB10_O            0xFFFFFFFF
#define E_DPI_PB11_O            0xFFFFFFFF
#define E_DPI_PB12_O            0xFFFFFFFF
#define E_DPI_PB13_O            0xFFFFFFFF
#define E_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define E_SPI_MISO_O            0xFFFFFFFF
#define E_SPI_MOSI_O            0xFFFFFFFF
#define E_SPI_CLK_O             0xFFFFFFFF
#define E_SPI_FLG0_O            0xFFFFFFFF
#define E_SPI_FLG1_O            0xFFFFFFFF
#define E_SPI_FLG2_O            0xFFFFFFFF
#define E_SPI_FLG3_O            0xFFFFFFFF

#define E_SPIB_MISO_O           0xFFFFFFFF
#define E_SPIB_MOSI_O           0xFFFFFFFF
#define E_SPIB_CLK_O            0xFFFFFFFF
#define E_SPIB_FLG0_O           0xFFFFFFFF
#define E_SPIB_FLG1_O           0xFFFFFFFF
#define E_SPIB_FLG2_O           0xFFFFFFFF
#define E_SPIB_FLG3_O           0xFFFFFFFF

#define E_SPI_MISO_PBEN_O       0xFFFFFFFF
#define E_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define E_SPI_CLK_PBEN_O        0xFFFFFFFF
#define E_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define E_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define E_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define E_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define E_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define E_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define E_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define E_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define E_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define E_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define E_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define E_FLAG4_O               0xFFFFFFFF
#define E_FLAG5_O               0xFFFFFFFF
#define E_FLAG6_O               0xFFFFFFFF
#define E_FLAG7_O               0xFFFFFFFF
#define E_FLAG8_O               0xFFFFFFFF
#define E_FLAG9_O               0xFFFFFFFF
#define E_FLAG10_O              0xFFFFFFFF
#define E_FLAG11_O              0xFFFFFFFF
#define E_FLAG12_O              0xFFFFFFFF
#define E_FLAG13_O              0xFFFFFFFF
#define E_FLAG14_O              0xFFFFFFFF
#define E_FLAG15_O              0xFFFFFFFF

#define E_PWM1_AL_O             0xFFFFFFFF
#define E_PWM1_AH_O             0xFFFFFFFF
#define E_PWM1_BL_O             0xFFFFFFFF
#define E_PWM1_BH_O             0xFFFFFFFF
#define E_PWM2_AL_O             0xFFFFFFFF
#define E_PWM2_AH_O             0xFFFFFFFF
#define E_PWM2_BL_O             0xFFFFFFFF
#define E_PWM2_BH_O             0xFFFFFFFF
#define E_PWM3_AL_O             0xFFFFFFFF
#define E_PWM3_AH_O             0xFFFFFFFF
#define E_PWM3_BL_O             0xFFFFFFFF
#define E_PWM3_BH_O             0xFFFFFFFF

#define E_FLAG4_PBEN_O         0xFFFFFFFF
#define E_FLAG5_PBEN_O         0xFFFFFFFF
#define E_FLAG6_PBEN_O         0xFFFFFFFF
#define E_FLAG7_PBEN_O         0xFFFFFFFF
#define E_FLAG8_PBEN_O         0xFFFFFFFF
#define E_FLAG9_PBEN_O         0xFFFFFFFF
#define E_FLAG10_PBEN_O         0xFFFFFFFF
#define E_FLAG11_PBEN_O         0xFFFFFFFF
#define E_FLAG12_PBEN_O         0xFFFFFFFF
#define E_FLAG13_PBEN_O         0xFFFFFFFF
#define E_FLAG14_PBEN_O         0xFFFFFFFF
#define E_FLAG15_PBEN_O         0xFFFFFFFF

#define E_PWM1_AL_PBEN_O             0xFFFFFFFF
#define E_PWM1_AH_PBEN_O             0xFFFFFFFF
#define E_PWM1_BL_PBEN_O             0xFFFFFFFF
#define E_PWM1_BH_PBEN_O             0xFFFFFFFF
#define E_PWM2_AL_PBEN_O             0xFFFFFFFF
#define E_PWM2_AH_PBEN_O             0xFFFFFFFF
#define E_PWM2_BL_PBEN_O             0xFFFFFFFF
#define E_PWM2_BH_PBEN_O             0xFFFFFFFF
#define E_PWM3_AL_PBEN_O             0xFFFFFFFF
#define E_PWM3_AH_PBEN_O             0xFFFFFFFF
#define E_PWM3_BL_PBEN_O             0xFFFFFFFF
#define E_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define E_MISCB0_O               0xFFFFFFFF
#define E_MISCB1_O               0xFFFFFFFF
#define E_MISCB2_O               0xFFFFFFFF
#define E_MISCB3_O               0xFFFFFFFF
#define E_MISCB4_O               0xFFFFFFFF
#define E_MISCB5_O               0xFFFFFFFF
#define E_MISCB6_O               0xFFFFFFFF
#define E_MISCB7_O               0xFFFFFFFF
#define E_MISCB8_O               0xFFFFFFFF
#define E_MISC0_O                0xFFFFFFFF
#define E_MISC1_O                0xFFFFFFFF
#define E_MISC2_O                0xFFFFFFFF
#define E_MISC3_O                0xFFFFFFFF
#define E_MISC4_O                0xFFFFFFFF
#define E_MISC5_O                0xFFFFFFFF
#define E_MISC6_O                0xFFFFFFFF
#define E_MISC7_O                0xFFFFFFFF
#define E_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define E_TIMER0_O              0xFFFFFFFF
#define E_TIMER1_O              0xFFFFFFFF
#define E_TIMER0_PBEN_O         0xFFFFFFFF
#define E_TIMER1_PBEN_O         0xFFFFFFFF

/* UART  */
#define E_UART0_TX_O            0xFFFFFFFF
#define E_UART0_TX_PBEN_O       0xFFFFFFFF

/*  TWI  */
#define E_TWI_DATA_PBEN_O       0xFFFFFFFF
#define E_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  E_SR_LAT_O              0xffffffff
#define  E_SR_SCLK_O             0xffffffff
#define  E_SR_SDAT_O             0xffffffff





/* DAI SRU Group F dummy signals */

#define F_DAI_PB01_O            0xFFFFFFFF
#define F_DAI_PB02_O            0xFFFFFFFF
#define F_DAI_PB03_O            0xFFFFFFFF
#define F_DAI_PB04_O            0xFFFFFFFF
#define F_DAI_PB05_O            0xFFFFFFFF
#define F_DAI_PB06_O            0xFFFFFFFF
#define F_DAI_PB07_O            0xFFFFFFFF
#define F_DAI_PB08_O            0xFFFFFFFF
#define F_DAI_PB09_O            0xFFFFFFFF
#define F_DAI_PB10_O            0xFFFFFFFF
#define F_DAI_PB11_O            0xFFFFFFFF
#define F_DAI_PB12_O            0xFFFFFFFF
#define F_DAI_PB13_O            0xFFFFFFFF
#define F_DAI_PB14_O            0xFFFFFFFF
#define F_DAI_PB15_O            0xFFFFFFFF
#define F_DAI_PB16_O            0xFFFFFFFF
#define F_DAI_PB17_O            0xFFFFFFFF
#define F_DAI_PB18_O            0xFFFFFFFF
#define F_DAI_PB19_O            0xFFFFFFFF
#define F_DAI_PB20_O            0xFFFFFFFF

/* SPORT */
#define F_SPORT0_CLK_O          0xFFFFFFFF
#define F_SPORT1_CLK_O          0xFFFFFFFF
#define F_SPORT2_CLK_O          0xFFFFFFFF
#define F_SPORT3_CLK_O          0xFFFFFFFF
#define F_SPORT4_CLK_O          0xFFFFFFFF
#define F_SPORT5_CLK_O          0xFFFFFFFF
#define F_SPORT6_CLK_O          0xFFFFFFFF
#define F_SPORT7_CLK_O          0xFFFFFFFF

#define F_SPORT0_FS_O           0xFFFFFFFF
#define F_SPORT1_FS_O           0xFFFFFFFF
#define F_SPORT2_FS_O           0xFFFFFFFF
#define F_SPORT3_FS_O           0xFFFFFFFF
#define F_SPORT4_FS_O           0xFFFFFFFF
#define F_SPORT5_FS_O           0xFFFFFFFF
#define F_SPORT6_FS_O           0xFFFFFFFF
#define F_SPORT7_FS_O           0xFFFFFFFF

#define F_SPORT0_DA_O           0xFFFFFFFF
#define F_SPORT1_DA_O           0xFFFFFFFF
#define F_SPORT2_DA_O           0xFFFFFFFF
#define F_SPORT3_DA_O           0xFFFFFFFF
#define F_SPORT4_DA_O           0xFFFFFFFF
#define F_SPORT5_DA_O           0xFFFFFFFF
#define F_SPORT6_DA_O           0xFFFFFFFF
#define F_SPORT7_DA_O           0xFFFFFFFF

#define F_SPORT0_DB_O           0xFFFFFFFF
#define F_SPORT1_DB_O           0xFFFFFFFF
#define F_SPORT2_DB_O           0xFFFFFFFF
#define F_SPORT3_DB_O           0xFFFFFFFF
#define F_SPORT4_DB_O           0xFFFFFFFF
#define F_SPORT5_DB_O           0xFFFFFFFF
#define F_SPORT6_DB_O           0xFFFFFFFF
#define F_SPORT7_DB_O           0xFFFFFFFF

#define F_SPORT0_TDV_O          0xFFFFFFFF
#define F_SPORT1_TDV_O          0xFFFFFFFF
#define F_SPORT2_TDV_O          0xFFFFFFFF
#define F_SPORT3_TDV_O          0xFFFFFFFF
#define F_SPORT4_TDV_O          0xFFFFFFFF
#define F_SPORT5_TDV_O          0xFFFFFFFF
#define F_SPORT6_TDV_O          0xFFFFFFFF
#define F_SPORT7_TDV_O          0xFFFFFFFF

/*  ASRC	*/
#define F_SRC0_DAT_OP_O         0xFFFFFFFF
#define F_SRC1_DAT_OP_O         0xFFFFFFFF
#define F_SRC2_DAT_OP_O         0xFFFFFFFF
#define F_SRC3_DAT_OP_O         0xFFFFFFFF
#define F_SRC0_TDM_IP_O         0xFFFFFFFF
#define F_SRC1_TDM_IP_O         0xFFFFFFFF
#define F_SRC2_TDM_IP_O         0xFFFFFFFF
#define F_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	F_PCG_CLKA_O			0xFFFFFFFF
#define	F_PCG_CLKB_O			0xFFFFFFFF
#define F_PCG_CLKC_O            0xFFFFFFFF
#define F_PCG_CLKD_O            0xFFFFFFFF
#define F_PCG_FSA_O           	0xFFFFFFFF
#define F_PCG_FSB_O           	0xFFFFFFFF
#define F_PCG_FSC_O             0xFFFFFFFF
#define F_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	F_DIR_CLK_O				0xFFFFFFFF
#define	F_DIR_TDMCLK_O			0xFFFFFFFF
#define F_DIR_FS_O           	0xFFFFFFFF
#define F_DIR_DAT_O		        0xFFFFFFFF
#define F_DIR_LRCLK_FB_O        0xFFFFFFFF
#define F_DIR_LRCLK_REF_O       0xFFFFFFFF
#define F_DIT_O			        0xFFFFFFFF
#define F_BLK_START_O           0xFFFFFFFF

/* MISCA	*/

/* PDAP	*/
#define F_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define F_DPI_PB01_O            0xFFFFFFFF
#define F_DPI_PB02_O            0xFFFFFFFF
#define F_DPI_PB03_O            0xFFFFFFFF
#define F_DPI_PB04_O            0xFFFFFFFF
#define F_DPI_PB05_O            0xFFFFFFFF
#define F_DPI_PB06_O            0xFFFFFFFF
#define F_DPI_PB07_O            0xFFFFFFFF
#define F_DPI_PB08_O            0xFFFFFFFF
#define F_DPI_PB09_O            0xFFFFFFFF
#define F_DPI_PB10_O            0xFFFFFFFF
#define F_DPI_PB11_O            0xFFFFFFFF
#define F_DPI_PB12_O            0xFFFFFFFF
#define F_DPI_PB13_O            0xFFFFFFFF
#define F_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define F_SPI_MISO_O            0xFFFFFFFF
#define F_SPI_MOSI_O            0xFFFFFFFF
#define F_SPI_CLK_O             0xFFFFFFFF
#define F_SPI_FLG0_O            0xFFFFFFFF
#define F_SPI_FLG1_O            0xFFFFFFFF
#define F_SPI_FLG2_O            0xFFFFFFFF
#define F_SPI_FLG3_O            0xFFFFFFFF

#define F_SPIB_MISO_O           0xFFFFFFFF
#define F_SPIB_MOSI_O           0xFFFFFFFF
#define F_SPIB_CLK_O            0xFFFFFFFF
#define F_SPIB_FLG0_O           0xFFFFFFFF
#define F_SPIB_FLG1_O           0xFFFFFFFF
#define F_SPIB_FLG2_O           0xFFFFFFFF
#define F_SPIB_FLG3_O           0xFFFFFFFF

#define F_SPI_MISO_PBEN_O       0xFFFFFFFF
#define F_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define F_SPI_CLK_PBEN_O        0xFFFFFFFF
#define F_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define F_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define F_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define F_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define F_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define F_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define F_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define F_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define F_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define F_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define F_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define F_FLAG4_O               0xFFFFFFFF
#define F_FLAG5_O               0xFFFFFFFF
#define F_FLAG6_O               0xFFFFFFFF
#define F_FLAG7_O               0xFFFFFFFF
#define F_FLAG8_O               0xFFFFFFFF
#define F_FLAG9_O               0xFFFFFFFF
#define F_FLAG10_O              0xFFFFFFFF
#define F_FLAG11_O              0xFFFFFFFF
#define F_FLAG12_O              0xFFFFFFFF
#define F_FLAG13_O              0xFFFFFFFF
#define F_FLAG14_O              0xFFFFFFFF
#define F_FLAG15_O              0xFFFFFFFF

#define F_PWM1_AL_O             0xFFFFFFFF
#define F_PWM1_AH_O             0xFFFFFFFF
#define F_PWM1_BL_O             0xFFFFFFFF
#define F_PWM1_BH_O             0xFFFFFFFF
#define F_PWM2_AL_O             0xFFFFFFFF
#define F_PWM2_AH_O             0xFFFFFFFF
#define F_PWM2_BL_O             0xFFFFFFFF
#define F_PWM2_BH_O             0xFFFFFFFF
#define F_PWM3_AL_O             0xFFFFFFFF
#define F_PWM3_AH_O             0xFFFFFFFF
#define F_PWM3_BL_O             0xFFFFFFFF
#define F_PWM3_BH_O             0xFFFFFFFF

#define F_FLAG4_PBEN_O         0xFFFFFFFF
#define F_FLAG5_PBEN_O         0xFFFFFFFF
#define F_FLAG6_PBEN_O         0xFFFFFFFF
#define F_FLAG7_PBEN_O         0xFFFFFFFF
#define F_FLAG8_PBEN_O         0xFFFFFFFF
#define F_FLAG9_PBEN_O         0xFFFFFFFF
#define F_FLAG10_PBEN_O         0xFFFFFFFF
#define F_FLAG11_PBEN_O         0xFFFFFFFF
#define F_FLAG12_PBEN_O         0xFFFFFFFF
#define F_FLAG13_PBEN_O         0xFFFFFFFF
#define F_FLAG14_PBEN_O         0xFFFFFFFF
#define F_FLAG15_PBEN_O         0xFFFFFFFF

#define F_PWM1_AL_PBEN_O             0xFFFFFFFF
#define F_PWM1_AH_PBEN_O             0xFFFFFFFF
#define F_PWM1_BL_PBEN_O             0xFFFFFFFF
#define F_PWM1_BH_PBEN_O             0xFFFFFFFF
#define F_PWM2_AL_PBEN_O             0xFFFFFFFF
#define F_PWM2_AH_PBEN_O             0xFFFFFFFF
#define F_PWM2_BL_PBEN_O             0xFFFFFFFF
#define F_PWM2_BH_PBEN_O             0xFFFFFFFF
#define F_PWM3_AL_PBEN_O             0xFFFFFFFF
#define F_PWM3_AH_PBEN_O             0xFFFFFFFF
#define F_PWM3_BL_PBEN_O             0xFFFFFFFF
#define F_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define F_MISCB0_O               0xFFFFFFFF
#define F_MISCB1_O               0xFFFFFFFF
#define F_MISCB2_O               0xFFFFFFFF
#define F_MISCB3_O               0xFFFFFFFF
#define F_MISCB4_O               0xFFFFFFFF
#define F_MISCB5_O               0xFFFFFFFF
#define F_MISCB6_O               0xFFFFFFFF
#define F_MISCB7_O               0xFFFFFFFF
#define F_MISCB8_O               0xFFFFFFFF
#define F_MISC0_O                0xFFFFFFFF
#define F_MISC1_O                0xFFFFFFFF
#define F_MISC2_O                0xFFFFFFFF
#define F_MISC3_O                0xFFFFFFFF
#define F_MISC4_O                0xFFFFFFFF
#define F_MISC5_O                0xFFFFFFFF
#define F_MISC6_O                0xFFFFFFFF
#define F_MISC7_O                0xFFFFFFFF
#define F_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define F_TIMER0_O              0xFFFFFFFF
#define F_TIMER1_O              0xFFFFFFFF
#define F_TIMER0_PBEN_O         0xFFFFFFFF
#define F_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define F_UART0_TX_O            0xFFFFFFFF
#define F_UART0_TX_PBEN_O       0xFFFFFFFF


/*  TWI  */
#define F_TWI_DATA_PBEN_O       0xFFFFFFFF
#define F_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  F_SR_LAT_O              0xffffffff
#define  F_SR_SCLK_O             0xffffffff
#define  F_SR_SDAT_O             0xffffffff






/* DAI SRU Group G dummy all DAI signals */

/* DAI Pin buffer  */
#define G_DAI_PB01_O            0xFFFFFFFF
#define G_DAI_PB02_O            0xFFFFFFFF
#define G_DAI_PB03_O            0xFFFFFFFF
#define G_DAI_PB04_O            0xFFFFFFFF
#define G_DAI_PB05_O            0xFFFFFFFF
#define G_DAI_PB06_O            0xFFFFFFFF
#define G_DAI_PB07_O            0xFFFFFFFF
#define G_DAI_PB08_O            0xFFFFFFFF
#define G_DAI_PB09_O            0xFFFFFFFF
#define G_DAI_PB10_O            0xFFFFFFFF
#define G_DAI_PB11_O            0xFFFFFFFF
#define G_DAI_PB12_O            0xFFFFFFFF
#define G_DAI_PB13_O            0xFFFFFFFF
#define G_DAI_PB14_O            0xFFFFFFFF
#define G_DAI_PB15_O            0xFFFFFFFF
#define G_DAI_PB16_O            0xFFFFFFFF
#define G_DAI_PB17_O            0xFFFFFFFF
#define G_DAI_PB18_O            0xFFFFFFFF
#define G_DAI_PB19_O            0xFFFFFFFF
#define G_DAI_PB20_O            0xFFFFFFFF

/* SPORT */
#define G_SPORT0_CLK_O          0xFFFFFFFF
#define G_SPORT1_CLK_O          0xFFFFFFFF
#define G_SPORT2_CLK_O          0xFFFFFFFF
#define G_SPORT3_CLK_O          0xFFFFFFFF
#define G_SPORT4_CLK_O          0xFFFFFFFF
#define G_SPORT5_CLK_O          0xFFFFFFFF
#define G_SPORT6_CLK_O          0xFFFFFFFF
#define G_SPORT7_CLK_O          0xFFFFFFFF

#define G_SPORT0_FS_O           0xFFFFFFFF
#define G_SPORT1_FS_O           0xFFFFFFFF
#define G_SPORT2_FS_O           0xFFFFFFFF
#define G_SPORT3_FS_O           0xFFFFFFFF
#define G_SPORT4_FS_O           0xFFFFFFFF
#define G_SPORT5_FS_O           0xFFFFFFFF
#define G_SPORT6_FS_O           0xFFFFFFFF
#define G_SPORT7_FS_O           0xFFFFFFFF

#define G_SPORT0_DA_O           0xFFFFFFFF
#define G_SPORT1_DA_O           0xFFFFFFFF
#define G_SPORT2_DA_O           0xFFFFFFFF
#define G_SPORT3_DA_O           0xFFFFFFFF
#define G_SPORT4_DA_O           0xFFFFFFFF
#define G_SPORT5_DA_O           0xFFFFFFFF
#define G_SPORT6_DA_O           0xFFFFFFFF
#define G_SPORT7_DA_O           0xFFFFFFFF

#define G_SPORT0_DB_O           0xFFFFFFFF
#define G_SPORT1_DB_O           0xFFFFFFFF
#define G_SPORT2_DB_O           0xFFFFFFFF
#define G_SPORT3_DB_O           0xFFFFFFFF
#define G_SPORT4_DB_O           0xFFFFFFFF
#define G_SPORT5_DB_O           0xFFFFFFFF
#define G_SPORT6_DB_O           0xFFFFFFFF
#define G_SPORT7_DB_O           0xFFFFFFFF

#define G_SPORT0_TDV_O          0xFFFFFFFF
#define G_SPORT1_TDV_O          0xFFFFFFFF
#define G_SPORT2_TDV_O          0xFFFFFFFF
#define G_SPORT3_TDV_O          0xFFFFFFFF
#define G_SPORT4_TDV_O          0xFFFFFFFF
#define G_SPORT5_TDV_O          0xFFFFFFFF
#define G_SPORT6_TDV_O          0xFFFFFFFF
#define G_SPORT7_TDV_O          0xFFFFFFFF

#define G_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define G_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define G_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define G_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define G_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define G_SRC0_DAT_OP_O         0xFFFFFFFF
#define G_SRC1_DAT_OP_O         0xFFFFFFFF
#define G_SRC2_DAT_OP_O         0xFFFFFFFF
#define G_SRC3_DAT_OP_O         0xFFFFFFFF
#define G_SRC0_TDM_IP_O         0xFFFFFFFF
#define G_SRC1_TDM_IP_O         0xFFFFFFFF
#define G_SRC2_TDM_IP_O         0xFFFFFFFF
#define G_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	G_PCG_CLKA_O			0xFFFFFFFF
#define	G_PCG_CLKB_O			0xFFFFFFFF
#define G_PCG_CLKC_O            0xFFFFFFFF
#define G_PCG_CLKD_O            0xFFFFFFFF
#define G_PCG_FSA_O           	0xFFFFFFFF
#define G_PCG_FSB_O           	0xFFFFFFFF
#define G_PCG_FSC_O             0xFFFFFFFF
#define G_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	G_DIR_CLK_O				0xFFFFFFFF
#define	G_DIR_TDMCLK_O			0xFFFFFFFF
#define G_DIR_FS_O           	0xFFFFFFFF
#define G_DIR_DAT_O		        0xFFFFFFFF
#define G_DIR_LRCLK_FB_O        0xFFFFFFFF
#define G_DIR_LRCLK_REF_O       0xFFFFFFFF
#define G_DIT_O			        0xFFFFFFFF
#define G_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define G_MISCA0_O              0xFFFFFFFF
#define G_MISCA1_O              0xFFFFFFFF
#define G_MISCA2_O              0xFFFFFFFF
#define G_MISCA3_O              0xFFFFFFFF
#define G_MISCA4_O              0xFFFFFFFF
#define G_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define G_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define G_DPI_PB01_O            0xFFFFFFFF
#define G_DPI_PB02_O            0xFFFFFFFF
#define G_DPI_PB03_O            0xFFFFFFFF
#define G_DPI_PB04_O            0xFFFFFFFF
#define G_DPI_PB05_O            0xFFFFFFFF
#define G_DPI_PB06_O            0xFFFFFFFF
#define G_DPI_PB07_O            0xFFFFFFFF
#define G_DPI_PB08_O            0xFFFFFFFF
#define G_DPI_PB09_O            0xFFFFFFFF
#define G_DPI_PB10_O            0xFFFFFFFF
#define G_DPI_PB11_O            0xFFFFFFFF
#define G_DPI_PB12_O            0xFFFFFFFF
#define G_DPI_PB13_O            0xFFFFFFFF
#define G_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define G_SPI_MISO_O            0xFFFFFFFF
#define G_SPI_MOSI_O            0xFFFFFFFF
#define G_SPI_CLK_O             0xFFFFFFFF
#define G_SPI_FLG0_O            0xFFFFFFFF
#define G_SPI_FLG1_O            0xFFFFFFFF
#define G_SPI_FLG2_O            0xFFFFFFFF
#define G_SPI_FLG3_O            0xFFFFFFFF

#define G_SPIB_MISO_O           0xFFFFFFFF
#define G_SPIB_MOSI_O           0xFFFFFFFF
#define G_SPIB_CLK_O            0xFFFFFFFF
#define G_SPIB_FLG0_O           0xFFFFFFFF
#define G_SPIB_FLG1_O           0xFFFFFFFF
#define G_SPIB_FLG2_O           0xFFFFFFFF
#define G_SPIB_FLG3_O           0xFFFFFFFF

#define G_SPI_MISO_PBEN_O       0xFFFFFFFF
#define G_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define G_SPI_CLK_PBEN_O        0xFFFFFFFF
#define G_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define G_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define G_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define G_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define G_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define G_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define G_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define G_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define G_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define G_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define G_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define G_FLAG4_O               0xFFFFFFFF
#define G_FLAG5_O               0xFFFFFFFF
#define G_FLAG6_O               0xFFFFFFFF
#define G_FLAG7_O               0xFFFFFFFF
#define G_FLAG8_O               0xFFFFFFFF
#define G_FLAG9_O               0xFFFFFFFF
#define G_FLAG10_O              0xFFFFFFFF
#define G_FLAG11_O              0xFFFFFFFF
#define G_FLAG12_O              0xFFFFFFFF
#define G_FLAG13_O              0xFFFFFFFF
#define G_FLAG14_O              0xFFFFFFFF
#define G_FLAG15_O              0xFFFFFFFF

#define G_PWM1_AL_O             0xFFFFFFFF
#define G_PWM1_AH_O             0xFFFFFFFF
#define G_PWM1_BL_O             0xFFFFFFFF
#define G_PWM1_BH_O             0xFFFFFFFF
#define G_PWM2_AL_O             0xFFFFFFFF
#define G_PWM2_AH_O             0xFFFFFFFF
#define G_PWM2_BL_O             0xFFFFFFFF
#define G_PWM2_BH_O             0xFFFFFFFF
#define G_PWM3_AL_O             0xFFFFFFFF
#define G_PWM3_AH_O             0xFFFFFFFF
#define G_PWM3_BL_O             0xFFFFFFFF
#define G_PWM3_BH_O             0xFFFFFFFF

#define G_FLAG4_PBEN_O         0xFFFFFFFF
#define G_FLAG5_PBEN_O         0xFFFFFFFF
#define G_FLAG6_PBEN_O         0xFFFFFFFF
#define G_FLAG7_PBEN_O         0xFFFFFFFF
#define G_FLAG8_PBEN_O         0xFFFFFFFF
#define G_FLAG9_PBEN_O         0xFFFFFFFF
#define G_FLAG10_PBEN_O         0xFFFFFFFF
#define G_FLAG11_PBEN_O         0xFFFFFFFF
#define G_FLAG12_PBEN_O         0xFFFFFFFF
#define G_FLAG13_PBEN_O         0xFFFFFFFF
#define G_FLAG14_PBEN_O         0xFFFFFFFF
#define G_FLAG15_PBEN_O         0xFFFFFFFF

#define G_PWM1_AL_PBEN_O             0xFFFFFFFF
#define G_PWM1_AH_PBEN_O             0xFFFFFFFF
#define G_PWM1_BL_PBEN_O             0xFFFFFFFF
#define G_PWM1_BH_PBEN_O             0xFFFFFFFF
#define G_PWM2_AL_PBEN_O             0xFFFFFFFF
#define G_PWM2_AH_PBEN_O             0xFFFFFFFF
#define G_PWM2_BL_PBEN_O             0xFFFFFFFF
#define G_PWM2_BH_PBEN_O             0xFFFFFFFF
#define G_PWM3_AL_PBEN_O             0xFFFFFFFF
#define G_PWM3_AH_PBEN_O             0xFFFFFFFF
#define G_PWM3_BL_PBEN_O             0xFFFFFFFF
#define G_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define G_MISCB0_O               0xFFFFFFFF
#define G_MISCB1_O               0xFFFFFFFF
#define G_MISCB2_O               0xFFFFFFFF
#define G_MISCB3_O               0xFFFFFFFF
#define G_MISCB4_O               0xFFFFFFFF
#define G_MISCB5_O               0xFFFFFFFF
#define G_MISCB6_O               0xFFFFFFFF
#define G_MISCB7_O               0xFFFFFFFF
#define G_MISCB8_O               0xFFFFFFFF
#define G_MISC0_O                0xFFFFFFFF
#define G_MISC1_O                0xFFFFFFFF
#define G_MISC2_O                0xFFFFFFFF
#define G_MISC3_O                0xFFFFFFFF
#define G_MISC4_O                0xFFFFFFFF
#define G_MISC5_O                0xFFFFFFFF
#define G_MISC6_O                0xFFFFFFFF
#define G_MISC7_O                0xFFFFFFFF
#define G_MISC8_O                0xFFFFFFFF

/* Timer	*/
#define G_TIMER0_O              0xFFFFFFFF
#define G_TIMER1_O              0xFFFFFFFF
#define G_TIMER0_PBEN_O         0xFFFFFFFF
#define G_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define G_UART0_TX_O            0xFFFFFFFF
#define G_UART0_TX_PBEN_O       0xFFFFFFFF

/*  TWI  */
#define G_TWI_DATA_PBEN_O       0xFFFFFFFF
#define G_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  G_SR_LAT_O              0xffffffff
#define  G_SR_SCLK_O             0xffffffff
#define  G_SR_SDAT_O             0xffffffff




/* DPI SRU Group A2 dummy signals */

/*  SPI  */
#define A2_SPI_MISO_O            0xFFFFFFFF
#define A2_SPI_MOSI_O            0xFFFFFFFF
#define A2_SPI_CLK_O             0xFFFFFFFF
#define A2_SPI_FLG0_O            0xFFFFFFFF
#define A2_SPI_FLG1_O            0xFFFFFFFF
#define A2_SPI_FLG2_O            0xFFFFFFFF
#define A2_SPI_FLG3_O            0xFFFFFFFF

#define A2_SPIB_MISO_O           0xFFFFFFFF
#define A2_SPIB_MOSI_O           0xFFFFFFFF
#define A2_SPIB_CLK_O            0xFFFFFFFF
#define A2_SPIB_FLG0_O           0xFFFFFFFF
#define A2_SPIB_FLG1_O           0xFFFFFFFF
#define A2_SPIB_FLG2_O           0xFFFFFFFF
#define A2_SPIB_FLG3_O           0xFFFFFFFF

#define A2_SPI_MISO_PBEN_O       0xFFFFFFFF
#define A2_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define A2_SPI_CLK_PBEN_O        0xFFFFFFFF
#define A2_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define A2_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define A2_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define A2_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define A2_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define A2_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define A2_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define A2_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define A2_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define A2_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define A2_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define A2_FLAG4_O               0xFFFFFFFF
#define A2_FLAG5_O               0xFFFFFFFF
#define A2_FLAG6_O               0xFFFFFFFF
#define A2_FLAG7_O               0xFFFFFFFF
#define A2_FLAG8_O               0xFFFFFFFF
#define A2_FLAG9_O               0xFFFFFFFF
#define A2_FLAG10_O              0xFFFFFFFF
#define A2_FLAG11_O              0xFFFFFFFF
#define A2_FLAG12_O              0xFFFFFFFF
#define A2_FLAG13_O              0xFFFFFFFF
#define A2_FLAG14_O              0xFFFFFFFF
#define A2_FLAG15_O              0xFFFFFFFF

#define A2_PWM1_AL_O             0xFFFFFFFF
#define A2_PWM1_AH_O             0xFFFFFFFF
#define A2_PWM1_BL_O             0xFFFFFFFF
#define A2_PWM1_BH_O             0xFFFFFFFF
#define A2_PWM2_AL_O             0xFFFFFFFF
#define A2_PWM2_AH_O             0xFFFFFFFF
#define A2_PWM2_BL_O             0xFFFFFFFF
#define A2_PWM2_BH_O             0xFFFFFFFF
#define A2_PWM3_AL_O             0xFFFFFFFF
#define A2_PWM3_AH_O             0xFFFFFFFF
#define A2_PWM3_BL_O             0xFFFFFFFF
#define A2_PWM3_BH_O             0xFFFFFFFF

#define A2_FLAG4_PBEN_O         0xFFFFFFFF
#define A2_FLAG5_PBEN_O         0xFFFFFFFF
#define A2_FLAG6_PBEN_O         0xFFFFFFFF
#define A2_FLAG7_PBEN_O         0xFFFFFFFF
#define A2_FLAG8_PBEN_O         0xFFFFFFFF
#define A2_FLAG9_PBEN_O         0xFFFFFFFF
#define A2_FLAG10_PBEN_O         0xFFFFFFFF
#define A2_FLAG11_PBEN_O         0xFFFFFFFF
#define A2_FLAG12_PBEN_O         0xFFFFFFFF
#define A2_FLAG13_PBEN_O         0xFFFFFFFF
#define A2_FLAG14_PBEN_O         0xFFFFFFFF
#define A2_FLAG15_PBEN_O         0xFFFFFFFF

#define A2_PWM1_AL_PBEN_O             0xFFFFFFFF
#define A2_PWM1_AH_PBEN_O             0xFFFFFFFF
#define A2_PWM1_BL_PBEN_O             0xFFFFFFFF
#define A2_PWM1_BH_PBEN_O             0xFFFFFFFF
#define A2_PWM2_AL_PBEN_O             0xFFFFFFFF
#define A2_PWM2_AH_PBEN_O             0xFFFFFFFF
#define A2_PWM2_BL_PBEN_O             0xFFFFFFFF
#define A2_PWM2_BH_PBEN_O             0xFFFFFFFF
#define A2_PWM3_AL_PBEN_O             0xFFFFFFFF
#define A2_PWM3_AH_PBEN_O             0xFFFFFFFF
#define A2_PWM3_BL_PBEN_O             0xFFFFFFFF
#define A2_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define A2_MISCB0_O               0xFFFFFFFF
#define A2_MISCB1_O               0xFFFFFFFF
#define A2_MISCB2_O               0xFFFFFFFF
#define A2_MISCB3_O               0xFFFFFFFF
#define A2_MISCB4_O               0xFFFFFFFF
#define A2_MISCB5_O               0xFFFFFFFF
#define A2_MISCB6_O               0xFFFFFFFF
#define A2_MISCB7_O               0xFFFFFFFF
#define A2_MISCB8_O               0xFFFFFFFF
#define A2_MISC0_O                0xFFFFFFFF
#define A2_MISC1_O                0xFFFFFFFF
#define A2_MISC2_O                0xFFFFFFFF
#define A2_MISC3_O                0xFFFFFFFF
#define A2_MISC4_O                0xFFFFFFFF
#define A2_MISC5_O                0xFFFFFFFF
#define A2_MISC6_O                0xFFFFFFFF
#define A2_MISC7_O                0xFFFFFFFF
#define A2_MISC8_O                0xFFFFFFFF

/* PCG 	*/
#define A2_PCG_CLKC_O            0xFFFFFFFF
#define A2_PCG_CLKD_O            0xFFFFFFFF
#define A2_PCG_FSC_O             0xFFFFFFFF
#define A2_PCG_FSD_O             0xFFFFFFFF

/* Timer	*/
#define A2_TIMER0_PBEN_O         0xFFFFFFFF
#define A2_TIMER1_PBEN_O         0xFFFFFFFF

/* UART  */
#define A2_UART0_TX_PBEN_O       0xFFFFFFFF

/*  TWI  */
#define A2_TWI_DATA_PBEN_O       0xFFFFFFFF
#define A2_TWI_CLK_PBEN_O        0xFFFFFFFF

/* ------- DAI signals --------  */
/* DAI Pin buffer  */
#define A2_DAI_PB01_O            0xFFFFFFFF
#define A2_DAI_PB02_O            0xFFFFFFFF
#define A2_DAI_PB03_O            0xFFFFFFFF
#define A2_DAI_PB04_O            0xFFFFFFFF
#define A2_DAI_PB05_O            0xFFFFFFFF
#define A2_DAI_PB06_O            0xFFFFFFFF
#define A2_DAI_PB07_O            0xFFFFFFFF
#define A2_DAI_PB08_O            0xFFFFFFFF
#define A2_DAI_PB09_O            0xFFFFFFFF
#define A2_DAI_PB10_O            0xFFFFFFFF
#define A2_DAI_PB11_O            0xFFFFFFFF
#define A2_DAI_PB12_O            0xFFFFFFFF
#define A2_DAI_PB13_O            0xFFFFFFFF
#define A2_DAI_PB14_O            0xFFFFFFFF
#define A2_DAI_PB15_O            0xFFFFFFFF
#define A2_DAI_PB16_O            0xFFFFFFFF
#define A2_DAI_PB17_O            0xFFFFFFFF
#define A2_DAI_PB18_O            0xFFFFFFFF
#define A2_DAI_PB19_O            0xFFFFFFFF
#define A2_DAI_PB20_O            0xFFFFFFFF

/* SPORT */
#define A2_SPORT0_CLK_O          0xFFFFFFFF
#define A2_SPORT1_CLK_O          0xFFFFFFFF
#define A2_SPORT2_CLK_O          0xFFFFFFFF
#define A2_SPORT3_CLK_O          0xFFFFFFFF
#define A2_SPORT4_CLK_O          0xFFFFFFFF
#define A2_SPORT5_CLK_O          0xFFFFFFFF
#define A2_SPORT6_CLK_O          0xFFFFFFFF
#define A2_SPORT7_CLK_O          0xFFFFFFFF

#define A2_SPORT0_FS_O           0xFFFFFFFF
#define A2_SPORT1_FS_O           0xFFFFFFFF
#define A2_SPORT2_FS_O           0xFFFFFFFF
#define A2_SPORT3_FS_O           0xFFFFFFFF
#define A2_SPORT4_FS_O           0xFFFFFFFF
#define A2_SPORT5_FS_O           0xFFFFFFFF
#define A2_SPORT6_FS_O           0xFFFFFFFF
#define A2_SPORT7_FS_O           0xFFFFFFFF

#define A2_SPORT0_DA_O           0xFFFFFFFF
#define A2_SPORT1_DA_O           0xFFFFFFFF
#define A2_SPORT2_DA_O           0xFFFFFFFF
#define A2_SPORT3_DA_O           0xFFFFFFFF
#define A2_SPORT4_DA_O           0xFFFFFFFF
#define A2_SPORT5_DA_O           0xFFFFFFFF
#define A2_SPORT6_DA_O           0xFFFFFFFF
#define A2_SPORT7_DA_O           0xFFFFFFFF

#define A2_SPORT0_DB_O           0xFFFFFFFF
#define A2_SPORT1_DB_O           0xFFFFFFFF
#define A2_SPORT2_DB_O           0xFFFFFFFF
#define A2_SPORT3_DB_O           0xFFFFFFFF
#define A2_SPORT4_DB_O           0xFFFFFFFF
#define A2_SPORT5_DB_O           0xFFFFFFFF
#define A2_SPORT6_DB_O           0xFFFFFFFF
#define A2_SPORT7_DB_O           0xFFFFFFFF

#define A2_SPORT0_TDV_O          0xFFFFFFFF
#define A2_SPORT1_TDV_O          0xFFFFFFFF
#define A2_SPORT2_TDV_O          0xFFFFFFFF
#define A2_SPORT3_TDV_O          0xFFFFFFFF
#define A2_SPORT4_TDV_O          0xFFFFFFFF
#define A2_SPORT5_TDV_O          0xFFFFFFFF
#define A2_SPORT6_TDV_O          0xFFFFFFFF
#define A2_SPORT7_TDV_O          0xFFFFFFFF

#define A2_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define A2_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define A2_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define A2_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define A2_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define A2_SRC0_DAT_OP_O         0xFFFFFFFF
#define A2_SRC1_DAT_OP_O         0xFFFFFFFF
#define A2_SRC2_DAT_OP_O         0xFFFFFFFF
#define A2_SRC3_DAT_OP_O         0xFFFFFFFF
#define A2_SRC0_TDM_IP_O         0xFFFFFFFF
#define A2_SRC1_TDM_IP_O         0xFFFFFFFF
#define A2_SRC2_TDM_IP_O         0xFFFFFFFF
#define A2_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	A2_PCG_CLKA_O			0xFFFFFFFF
#define	A2_PCG_CLKB_O			0xFFFFFFFF
#define A2_PCG_CLKC_O            0xFFFFFFFF
#define A2_PCG_CLKD_O            0xFFFFFFFF
#define A2_PCG_FSA_O           	0xFFFFFFFF
#define A2_PCG_FSB_O           	0xFFFFFFFF
#define A2_PCG_FSC_O             0xFFFFFFFF
#define A2_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	A2_DIR_CLK_O				0xFFFFFFFF
#define	A2_DIR_TDMCLK_O			0xFFFFFFFF
#define A2_DIR_FS_O           	0xFFFFFFFF
#define A2_DIR_DAT_O		        0xFFFFFFFF
#define A2_DIR_LRCLK_FB_O        0xFFFFFFFF
#define A2_DIR_LRCLK_REF_O       0xFFFFFFFF
#define A2_DIT_O			        0xFFFFFFFF
#define A2_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define A2_MISCA0_O              0xFFFFFFFF
#define A2_MISCA1_O              0xFFFFFFFF
#define A2_MISCA2_O              0xFFFFFFFF
#define A2_MISCA3_O              0xFFFFFFFF
#define A2_MISCA4_O              0xFFFFFFFF
#define A2_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define A2_PDAP_STRB_O           0xFFFFFFFF



/* Shift Register */

#define  A2_SR_LAT_O              0xffffffff
#define  A2_SR_SCLK_O             0xffffffff
#define  A2_SR_SDAT_O             0xffffffff






/* DPI SRU Group B2 dummy signals */

/*  SPI  */
#define B2_SPI_MISO_PBEN_O       0xFFFFFFFF
#define B2_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define B2_SPI_CLK_PBEN_O        0xFFFFFFFF
#define B2_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define B2_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define B2_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define B2_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define B2_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define B2_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define B2_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define B2_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define B2_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define B2_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define B2_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define B2_FLAG4_PBEN_O         0xFFFFFFFF
#define B2_FLAG5_PBEN_O         0xFFFFFFFF
#define B2_FLAG6_PBEN_O         0xFFFFFFFF
#define B2_FLAG7_PBEN_O         0xFFFFFFFF
#define B2_FLAG8_PBEN_O         0xFFFFFFFF
#define B2_FLAG9_PBEN_O         0xFFFFFFFF
#define B2_FLAG10_PBEN_O         0xFFFFFFFF
#define B2_FLAG11_PBEN_O         0xFFFFFFFF
#define B2_FLAG12_PBEN_O         0xFFFFFFFF
#define B2_FLAG13_PBEN_O         0xFFFFFFFF
#define B2_FLAG14_PBEN_O         0xFFFFFFFF
#define B2_FLAG15_PBEN_O         0xFFFFFFFF

#define B2_PWM1_AL_PBEN_O             0xFFFFFFFF
#define B2_PWM1_AH_PBEN_O             0xFFFFFFFF
#define B2_PWM1_BL_PBEN_O             0xFFFFFFFF
#define B2_PWM1_BH_PBEN_O             0xFFFFFFFF
#define B2_PWM2_AL_PBEN_O             0xFFFFFFFF
#define B2_PWM2_AH_PBEN_O             0xFFFFFFFF
#define B2_PWM2_BL_PBEN_O             0xFFFFFFFF
#define B2_PWM2_BH_PBEN_O             0xFFFFFFFF
#define B2_PWM3_AL_PBEN_O             0xFFFFFFFF
#define B2_PWM3_AH_PBEN_O             0xFFFFFFFF
#define B2_PWM3_BL_PBEN_O             0xFFFFFFFF
#define B2_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define B2_MISCB0_O               0xFFFFFFFF
#define B2_MISCB1_O               0xFFFFFFFF
#define B2_MISCB2_O               0xFFFFFFFF
#define B2_MISCB3_O               0xFFFFFFFF
#define B2_MISCB4_O               0xFFFFFFFF
#define B2_MISCB5_O               0xFFFFFFFF
#define B2_MISCB6_O               0xFFFFFFFF
#define B2_MISCB7_O               0xFFFFFFFF
#define B2_MISCB8_O               0xFFFFFFFF
#define B2_MISC0_O                0xFFFFFFFF
#define B2_MISC1_O                0xFFFFFFFF
#define B2_MISC2_O                0xFFFFFFFF
#define B2_MISC3_O                0xFFFFFFFF
#define B2_MISC4_O                0xFFFFFFFF
#define B2_MISC5_O                0xFFFFFFFF
#define B2_MISC6_O                0xFFFFFFFF
#define B2_MISC7_O                0xFFFFFFFF
#define B2_MISC8_O                0xFFFFFFFF

/* PCG 	*/

/* Timer	*/
#define B2_TIMER0_PBEN_O         0xFFFFFFFF
#define B2_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define B2_UART0_TX_PBEN_O       0xFFFFFFFF


/*  TWI  */
#define B2_TWI_DATA_PBEN_O       0xFFFFFFFF
#define B2_TWI_CLK_PBEN_O        0xFFFFFFFF

/* ------- DAI signals --------  */
/* DAI Pin buffer  */
#define B2_DAI_PB01_O            0xFFFFFFFF
#define B2_DAI_PB02_O            0xFFFFFFFF
#define B2_DAI_PB03_O            0xFFFFFFFF
#define B2_DAI_PB04_O            0xFFFFFFFF
#define B2_DAI_PB05_O            0xFFFFFFFF
#define B2_DAI_PB06_O            0xFFFFFFFF
#define B2_DAI_PB07_O            0xFFFFFFFF
#define B2_DAI_PB08_O            0xFFFFFFFF
#define B2_DAI_PB09_O            0xFFFFFFFF
#define B2_DAI_PB10_O            0xFFFFFFFF
#define B2_DAI_PB11_O            0xFFFFFFFF
#define B2_DAI_PB12_O            0xFFFFFFFF
#define B2_DAI_PB13_O            0xFFFFFFFF
#define B2_DAI_PB14_O            0xFFFFFFFF
#define B2_DAI_PB15_O            0xFFFFFFFF
#define B2_DAI_PB16_O            0xFFFFFFFF
#define B2_DAI_PB17_O            0xFFFFFFFF
#define B2_DAI_PB18_O            0xFFFFFFFF
#define B2_DAI_PB19_O            0xFFFFFFFF
#define B2_DAI_PB20_O            0xFFFFFFFF

/* SPORT */
#define B2_SPORT0_CLK_O          0xFFFFFFFF
#define B2_SPORT1_CLK_O          0xFFFFFFFF
#define B2_SPORT2_CLK_O          0xFFFFFFFF
#define B2_SPORT3_CLK_O          0xFFFFFFFF
#define B2_SPORT4_CLK_O          0xFFFFFFFF
#define B2_SPORT5_CLK_O          0xFFFFFFFF
#define B2_SPORT6_CLK_O          0xFFFFFFFF
#define B2_SPORT7_CLK_O          0xFFFFFFFF

#define B2_SPORT0_FS_O           0xFFFFFFFF
#define B2_SPORT1_FS_O           0xFFFFFFFF
#define B2_SPORT2_FS_O           0xFFFFFFFF
#define B2_SPORT3_FS_O           0xFFFFFFFF
#define B2_SPORT4_FS_O           0xFFFFFFFF
#define B2_SPORT5_FS_O           0xFFFFFFFF
#define B2_SPORT6_FS_O           0xFFFFFFFF
#define B2_SPORT7_FS_O           0xFFFFFFFF

#define B2_SPORT0_DA_O           0xFFFFFFFF
#define B2_SPORT1_DA_O           0xFFFFFFFF
#define B2_SPORT2_DA_O           0xFFFFFFFF
#define B2_SPORT3_DA_O           0xFFFFFFFF
#define B2_SPORT4_DA_O           0xFFFFFFFF
#define B2_SPORT5_DA_O           0xFFFFFFFF
#define B2_SPORT6_DA_O           0xFFFFFFFF
#define B2_SPORT7_DA_O           0xFFFFFFFF

#define B2_SPORT0_DB_O           0xFFFFFFFF
#define B2_SPORT1_DB_O           0xFFFFFFFF
#define B2_SPORT2_DB_O           0xFFFFFFFF
#define B2_SPORT3_DB_O           0xFFFFFFFF
#define B2_SPORT4_DB_O           0xFFFFFFFF
#define B2_SPORT5_DB_O           0xFFFFFFFF
#define B2_SPORT6_DB_O           0xFFFFFFFF
#define B2_SPORT7_DB_O           0xFFFFFFFF

#define B2_SPORT0_TDV_O          0xFFFFFFFF
#define B2_SPORT1_TDV_O          0xFFFFFFFF
#define B2_SPORT2_TDV_O          0xFFFFFFFF
#define B2_SPORT3_TDV_O          0xFFFFFFFF
#define B2_SPORT4_TDV_O          0xFFFFFFFF
#define B2_SPORT5_TDV_O          0xFFFFFFFF
#define B2_SPORT6_TDV_O          0xFFFFFFFF
#define B2_SPORT7_TDV_O          0xFFFFFFFF

#define B2_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define B2_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define B2_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define B2_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define B2_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define B2_SRC0_DAT_OP_O         0xFFFFFFFF
#define B2_SRC1_DAT_OP_O         0xFFFFFFFF
#define B2_SRC2_DAT_OP_O         0xFFFFFFFF
#define B2_SRC3_DAT_OP_O         0xFFFFFFFF
#define B2_SRC0_TDM_IP_O         0xFFFFFFFF
#define B2_SRC1_TDM_IP_O         0xFFFFFFFF
#define B2_SRC2_TDM_IP_O         0xFFFFFFFF
#define B2_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	B2_PCG_CLKA_O			0xFFFFFFFF
#define	B2_PCG_CLKB_O			0xFFFFFFFF
#define B2_PCG_FSA_O           	0xFFFFFFFF
#define B2_PCG_FSB_O           	0xFFFFFFFF

/* 	S/PDIF  */
#define	B2_DIR_CLK_O				0xFFFFFFFF
#define	B2_DIR_TDMCLK_O			0xFFFFFFFF
#define B2_DIR_FS_O           	0xFFFFFFFF
#define B2_DIR_DAT_O		        0xFFFFFFFF
#define B2_DIR_LRCLK_FB_O        0xFFFFFFFF
#define B2_DIR_LRCLK_REF_O       0xFFFFFFFF
#define B2_DIT_O			        0xFFFFFFFF
#define B2_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define B2_MISCA0_O              0xFFFFFFFF
#define B2_MISCA1_O              0xFFFFFFFF
#define B2_MISCA2_O              0xFFFFFFFF
#define B2_MISCA3_O              0xFFFFFFFF
#define B2_MISCA4_O              0xFFFFFFFF
#define B2_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define B2_PDAP_STRB_O           0xFFFFFFFF

/* Shift Register */

#define  B2_SR_LAT_O              0xffffffff
#define  B2_SR_SCLK_O             0xffffffff
#define  B2_SR_SDAT_O             0xffffffff








/* DPI SRU Group C2 dummy signals */

/* DPI Pin buffer  */
#define C2_DPI_PB01_O            0xFFFFFFFF
#define C2_DPI_PB02_O            0xFFFFFFFF
#define C2_DPI_PB03_O            0xFFFFFFFF
#define C2_DPI_PB04_O            0xFFFFFFFF
#define C2_DPI_PB05_O            0xFFFFFFFF
#define C2_DPI_PB06_O            0xFFFFFFFF
#define C2_DPI_PB07_O            0xFFFFFFFF
#define C2_DPI_PB08_O            0xFFFFFFFF
#define C2_DPI_PB09_O            0xFFFFFFFF
#define C2_DPI_PB10_O            0xFFFFFFFF
#define C2_DPI_PB11_O            0xFFFFFFFF
#define C2_DPI_PB12_O            0xFFFFFFFF
#define C2_DPI_PB13_O            0xFFFFFFFF
#define C2_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define C2_SPI_MISO_O            0xFFFFFFFF
#define C2_SPI_MOSI_O            0xFFFFFFFF
#define C2_SPI_CLK_O             0xFFFFFFFF
#define C2_SPI_FLG0_O            0xFFFFFFFF
#define C2_SPI_FLG1_O            0xFFFFFFFF
#define C2_SPI_FLG2_O            0xFFFFFFFF
#define C2_SPI_FLG3_O            0xFFFFFFFF

#define C2_SPIB_MISO_O           0xFFFFFFFF
#define C2_SPIB_MOSI_O           0xFFFFFFFF
#define C2_SPIB_CLK_O            0xFFFFFFFF
#define C2_SPIB_FLG0_O           0xFFFFFFFF
#define C2_SPIB_FLG1_O           0xFFFFFFFF
#define C2_SPIB_FLG2_O           0xFFFFFFFF
#define C2_SPIB_FLG3_O           0xFFFFFFFF
/* FLAG	 */
#define C2_FLAG4_O               0xFFFFFFFF
#define C2_FLAG5_O               0xFFFFFFFF
#define C2_FLAG6_O               0xFFFFFFFF
#define C2_FLAG7_O               0xFFFFFFFF
#define C2_FLAG8_O               0xFFFFFFFF
#define C2_FLAG9_O               0xFFFFFFFF
#define C2_FLAG10_O              0xFFFFFFFF
#define C2_FLAG11_O              0xFFFFFFFF
#define C2_FLAG12_O              0xFFFFFFFF
#define C2_FLAG13_O              0xFFFFFFFF
#define C2_FLAG14_O              0xFFFFFFFF
#define C2_FLAG15_O              0xFFFFFFFF

#define C2_PWM1_AL_O             0xFFFFFFFF
#define C2_PWM1_AH_O             0xFFFFFFFF
#define C2_PWM1_BL_O             0xFFFFFFFF
#define C2_PWM1_BH_O             0xFFFFFFFF
#define C2_PWM2_AL_O             0xFFFFFFFF
#define C2_PWM2_AH_O             0xFFFFFFFF
#define C2_PWM2_BL_O             0xFFFFFFFF
#define C2_PWM2_BH_O             0xFFFFFFFF
#define C2_PWM3_AL_O             0xFFFFFFFF
#define C2_PWM3_AH_O             0xFFFFFFFF
#define C2_PWM3_BL_O             0xFFFFFFFF
#define C2_PWM3_BH_O             0xFFFFFFFF

/*  MISCB  */


/* Timer	*/
#define C2_TIMER0_O              0xFFFFFFFF
#define C2_TIMER1_O              0xFFFFFFFF


/* UART  */
#define C2_UART0_TX_O            0xFFFFFFFF


/*  TWI  */

/* ------- DAI signals --------  */
/* DAI Pin buffer  */
#define C2_DAI_PB01_O            0xFFFFFFFF
#define C2_DAI_PB02_O            0xFFFFFFFF
#define C2_DAI_PB03_O            0xFFFFFFFF
#define C2_DAI_PB04_O            0xFFFFFFFF
#define C2_DAI_PB05_O            0xFFFFFFFF
#define C2_DAI_PB06_O            0xFFFFFFFF
#define C2_DAI_PB07_O            0xFFFFFFFF
#define C2_DAI_PB08_O            0xFFFFFFFF
#define C2_DAI_PB09_O            0xFFFFFFFF
#define C2_DAI_PB10_O            0xFFFFFFFF
#define C2_DAI_PB11_O            0xFFFFFFFF
#define C2_DAI_PB12_O            0xFFFFFFFF
#define C2_DAI_PB13_O            0xFFFFFFFF
#define C2_DAI_PB14_O            0xFFFFFFFF
#define C2_DAI_PB15_O            0xFFFFFFFF
#define C2_DAI_PB16_O            0xFFFFFFFF
#define C2_DAI_PB17_O            0xFFFFFFFF
#define C2_DAI_PB18_O            0xFFFFFFFF
#define C2_DAI_PB19_O            0xFFFFFFFF
#define C2_DAI_PB20_O            0xFFFFFFFF

/* SPORT */
#define C2_SPORT0_CLK_O          0xFFFFFFFF
#define C2_SPORT1_CLK_O          0xFFFFFFFF
#define C2_SPORT2_CLK_O          0xFFFFFFFF
#define C2_SPORT3_CLK_O          0xFFFFFFFF
#define C2_SPORT4_CLK_O          0xFFFFFFFF
#define C2_SPORT5_CLK_O          0xFFFFFFFF
#define C2_SPORT6_CLK_O          0xFFFFFFFF
#define C2_SPORT7_CLK_O          0xFFFFFFFF

#define C2_SPORT0_FS_O           0xFFFFFFFF
#define C2_SPORT1_FS_O           0xFFFFFFFF
#define C2_SPORT2_FS_O           0xFFFFFFFF
#define C2_SPORT3_FS_O           0xFFFFFFFF
#define C2_SPORT4_FS_O           0xFFFFFFFF
#define C2_SPORT5_FS_O           0xFFFFFFFF
#define C2_SPORT6_FS_O           0xFFFFFFFF
#define C2_SPORT7_FS_O           0xFFFFFFFF

#define C2_SPORT0_DA_O           0xFFFFFFFF
#define C2_SPORT1_DA_O           0xFFFFFFFF
#define C2_SPORT2_DA_O           0xFFFFFFFF
#define C2_SPORT3_DA_O           0xFFFFFFFF
#define C2_SPORT4_DA_O           0xFFFFFFFF
#define C2_SPORT5_DA_O           0xFFFFFFFF
#define C2_SPORT6_DA_O           0xFFFFFFFF
#define C2_SPORT7_DA_O           0xFFFFFFFF

#define C2_SPORT0_DB_O           0xFFFFFFFF
#define C2_SPORT1_DB_O           0xFFFFFFFF
#define C2_SPORT2_DB_O           0xFFFFFFFF
#define C2_SPORT3_DB_O           0xFFFFFFFF
#define C2_SPORT4_DB_O           0xFFFFFFFF
#define C2_SPORT5_DB_O           0xFFFFFFFF
#define C2_SPORT6_DB_O           0xFFFFFFFF
#define C2_SPORT7_DB_O           0xFFFFFFFF

#define C2_SPORT0_TDV_O          0xFFFFFFFF
#define C2_SPORT1_TDV_O          0xFFFFFFFF
#define C2_SPORT2_TDV_O          0xFFFFFFFF
#define C2_SPORT3_TDV_O          0xFFFFFFFF
#define C2_SPORT4_TDV_O          0xFFFFFFFF
#define C2_SPORT5_TDV_O          0xFFFFFFFF
#define C2_SPORT6_TDV_O          0xFFFFFFFF
#define C2_SPORT7_TDV_O          0xFFFFFFFF

#define C2_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define C2_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define C2_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define C2_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define C2_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define C2_SRC0_DAT_OP_O         0xFFFFFFFF
#define C2_SRC1_DAT_OP_O         0xFFFFFFFF
#define C2_SRC2_DAT_OP_O         0xFFFFFFFF
#define C2_SRC3_DAT_OP_O         0xFFFFFFFF
#define C2_SRC0_TDM_IP_O         0xFFFFFFFF
#define C2_SRC1_TDM_IP_O         0xFFFFFFFF
#define C2_SRC2_TDM_IP_O         0xFFFFFFFF
#define C2_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/
#define	C2_PCG_CLKA_O			0xFFFFFFFF
#define	C2_PCG_CLKB_O			0xFFFFFFFF
#define C2_PCG_CLKC_O            0xFFFFFFFF
#define C2_PCG_CLKD_O            0xFFFFFFFF
#define C2_PCG_FSA_O           	0xFFFFFFFF
#define C2_PCG_FSB_O           	0xFFFFFFFF
#define C2_PCG_FSC_O             0xFFFFFFFF
#define C2_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	C2_DIR_CLK_O				0xFFFFFFFF
#define	C2_DIR_TDMCLK_O			0xFFFFFFFF
#define C2_DIR_FS_O           	0xFFFFFFFF
#define C2_DIR_DAT_O		        0xFFFFFFFF
#define C2_DIR_LRCLK_FB_O        0xFFFFFFFF
#define C2_DIR_LRCLK_REF_O       0xFFFFFFFF
#define C2_DIT_O			        0xFFFFFFFF
#define C2_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define C2_MISCA0_O              0xFFFFFFFF
#define C2_MISCA1_O              0xFFFFFFFF
#define C2_MISCA2_O              0xFFFFFFFF
#define C2_MISCA3_O              0xFFFFFFFF
#define C2_MISCA4_O              0xFFFFFFFF
#define C2_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define C2_PDAP_STRB_O           0xFFFFFFFF

/* Shift Register */

#define  C2_SR_LAT_O              0xffffffff
#define  C2_SR_SCLK_O             0xffffffff
#define  C2_SR_SDAT_O             0xffffffff



/* DAI SRU Group H dummy signals */

/* DAI Pin buffer  */

#define H_DAI_PB09_O            0xFFFFFFFF
#define H_DAI_PB10_O            0xFFFFFFFF
#define H_DAI_PB11_O            0xFFFFFFFF
#define H_DAI_PB12_O            0xFFFFFFFF
#define H_DAI_PB13_O            0xFFFFFFFF
#define H_DAI_PB14_O            0xFFFFFFFF
#define H_DAI_PB15_O            0xFFFFFFFF
#define H_DAI_PB16_O            0xFFFFFFFF
#define H_DAI_PB17_O            0xFFFFFFFF
#define H_DAI_PB18_O            0xFFFFFFFF
#define H_DAI_PB19_O            0xFFFFFFFF
#define H_DAI_PB20_O            0xFFFFFFFF

/* SPORT */

#define H_SPORT0_DA_O           0xFFFFFFFF
#define H_SPORT1_DA_O           0xFFFFFFFF
#define H_SPORT2_DA_O           0xFFFFFFFF
#define H_SPORT3_DA_O           0xFFFFFFFF
#define H_SPORT4_DA_O           0xFFFFFFFF
#define H_SPORT5_DA_O           0xFFFFFFFF
#define H_SPORT6_DA_O           0xFFFFFFFF
#define H_SPORT7_DA_O           0xFFFFFFFF

#define H_SPORT0_DB_O           0xFFFFFFFF
#define H_SPORT1_DB_O           0xFFFFFFFF
#define H_SPORT2_DB_O           0xFFFFFFFF
#define H_SPORT3_DB_O           0xFFFFFFFF
#define H_SPORT4_DB_O           0xFFFFFFFF
#define H_SPORT5_DB_O           0xFFFFFFFF
#define H_SPORT6_DB_O           0xFFFFFFFF
#define H_SPORT7_DB_O           0xFFFFFFFF


#define H_SPORT0_TDV_O          0xFFFFFFFF
#define H_SPORT1_TDV_O          0xFFFFFFFF
#define H_SPORT2_TDV_O          0xFFFFFFFF
#define H_SPORT3_TDV_O          0xFFFFFFFF
#define H_SPORT4_TDV_O          0xFFFFFFFF
#define H_SPORT5_TDV_O          0xFFFFFFFF
#define H_SPORT6_TDV_O          0xFFFFFFFF
#define H_SPORT7_TDV_O          0xFFFFFFFF

#define H_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define H_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define H_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define H_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define H_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define H_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define H_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define H_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define H_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define H_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define H_SRC0_DAT_OP_O         0xFFFFFFFF
#define H_SRC1_DAT_OP_O         0xFFFFFFFF
#define H_SRC2_DAT_OP_O         0xFFFFFFFF
#define H_SRC3_DAT_OP_O         0xFFFFFFFF
#define H_SRC0_TDM_IP_O         0xFFFFFFFF
#define H_SRC1_TDM_IP_O         0xFFFFFFFF
#define H_SRC2_TDM_IP_O         0xFFFFFFFF
#define H_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/

#define H_PCG_CLKC_O            0xFFFFFFFF
#define H_PCG_CLKD_O            0xFFFFFFFF
#define H_PCG_FSC_O             0xFFFFFFFF
#define H_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	H_DIR_CLK_O				0xFFFFFFFF
#define	H_DIR_TDMCLK_O			0xFFFFFFFF
#define H_DIR_FS_O           	0xFFFFFFFF
#define H_DIR_DAT_O		        0xFFFFFFFF
#define H_DIR_LRCLK_FB_O        0xFFFFFFFF
#define H_DIR_LRCLK_REF_O       0xFFFFFFFF
#define H_DIT_O			        0xFFFFFFFF
#define H_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define H_MISCA0_O              0xFFFFFFFF
#define H_MISCA1_O              0xFFFFFFFF
#define H_MISCA2_O              0xFFFFFFFF
#define H_MISCA3_O              0xFFFFFFFF
#define H_MISCA4_O              0xFFFFFFFF
#define H_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define H_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define H_DPI_PB01_O            0xFFFFFFFF
#define H_DPI_PB02_O            0xFFFFFFFF
#define H_DPI_PB03_O            0xFFFFFFFF
#define H_DPI_PB04_O            0xFFFFFFFF
#define H_DPI_PB05_O            0xFFFFFFFF
#define H_DPI_PB06_O            0xFFFFFFFF
#define H_DPI_PB07_O            0xFFFFFFFF
#define H_DPI_PB08_O            0xFFFFFFFF
#define H_DPI_PB09_O            0xFFFFFFFF
#define H_DPI_PB10_O            0xFFFFFFFF
#define H_DPI_PB11_O            0xFFFFFFFF
#define H_DPI_PB12_O            0xFFFFFFFF
#define H_DPI_PB13_O            0xFFFFFFFF
#define H_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define H_SPI_MISO_O            0xFFFFFFFF
#define H_SPI_MOSI_O            0xFFFFFFFF
#define H_SPI_CLK_O             0xFFFFFFFF
#define H_SPI_FLG0_O            0xFFFFFFFF
#define H_SPI_FLG1_O            0xFFFFFFFF
#define H_SPI_FLG2_O            0xFFFFFFFF
#define H_SPI_FLG3_O            0xFFFFFFFF

#define H_SPIB_MISO_O           0xFFFFFFFF
#define H_SPIB_MOSI_O           0xFFFFFFFF
#define H_SPIB_CLK_O            0xFFFFFFFF
#define H_SPIB_FLG0_O           0xFFFFFFFF
#define H_SPIB_FLG1_O           0xFFFFFFFF
#define H_SPIB_FLG2_O           0xFFFFFFFF
#define H_SPIB_FLG3_O           0xFFFFFFFF

#define H_SPI_MISO_PBEN_O       0xFFFFFFFF
#define H_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define H_SPI_CLK_PBEN_O        0xFFFFFFFF
#define H_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define H_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define H_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define H_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define H_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define H_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define H_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define H_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define H_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define H_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define H_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define H_FLAG4_O               0xFFFFFFFF
#define H_FLAG5_O               0xFFFFFFFF
#define H_FLAG6_O               0xFFFFFFFF
#define H_FLAG7_O               0xFFFFFFFF
#define H_FLAG8_O               0xFFFFFFFF
#define H_FLAG9_O               0xFFFFFFFF
#define H_FLAG10_O              0xFFFFFFFF
#define H_FLAG11_O              0xFFFFFFFF
#define H_FLAG12_O              0xFFFFFFFF
#define H_FLAG13_O              0xFFFFFFFF
#define H_FLAG14_O              0xFFFFFFFF
#define H_FLAG15_O              0xFFFFFFFF



#define H_FLAG4_PBEN_O         0xFFFFFFFF
#define H_FLAG5_PBEN_O         0xFFFFFFFF
#define H_FLAG6_PBEN_O         0xFFFFFFFF
#define H_FLAG7_PBEN_O         0xFFFFFFFF
#define H_FLAG8_PBEN_O         0xFFFFFFFF
#define H_FLAG9_PBEN_O         0xFFFFFFFF
#define H_FLAG10_PBEN_O         0xFFFFFFFF
#define H_FLAG11_PBEN_O         0xFFFFFFFF
#define H_FLAG12_PBEN_O         0xFFFFFFFF
#define H_FLAG13_PBEN_O         0xFFFFFFFF
#define H_FLAG14_PBEN_O         0xFFFFFFFF
#define H_FLAG15_PBEN_O         0xFFFFFFFF

#define H_PWM1_AL_O             0xFFFFFFFF
#define H_PWM1_AH_O             0xFFFFFFFF
#define H_PWM1_BL_O             0xFFFFFFFF
#define H_PWM1_BH_O             0xFFFFFFFF
#define H_PWM2_AL_O             0xFFFFFFFF
#define H_PWM2_AH_O             0xFFFFFFFF
#define H_PWM2_BL_O             0xFFFFFFFF
#define H_PWM2_BH_O             0xFFFFFFFF
#define H_PWM3_AL_O             0xFFFFFFFF
#define H_PWM3_AH_O             0xFFFFFFFF
#define H_PWM3_BL_O             0xFFFFFFFF
#define H_PWM3_BH_O             0xFFFFFFFF

#define H_PWM1_AL_PBEN_O             0xFFFFFFFF
#define H_PWM1_AH_PBEN_O             0xFFFFFFFF
#define H_PWM1_BL_PBEN_O             0xFFFFFFFF
#define H_PWM1_BH_PBEN_O             0xFFFFFFFF
#define H_PWM2_AL_PBEN_O             0xFFFFFFFF
#define H_PWM2_AH_PBEN_O             0xFFFFFFFF
#define H_PWM2_BL_PBEN_O             0xFFFFFFFF
#define H_PWM2_BH_PBEN_O             0xFFFFFFFF
#define H_PWM3_AL_PBEN_O             0xFFFFFFFF
#define H_PWM3_AH_PBEN_O             0xFFFFFFFF
#define H_PWM3_BL_PBEN_O             0xFFFFFFFF
#define H_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define H_MISCB0_O               0xFFFFFFFF
#define H_MISCB1_O               0xFFFFFFFF
#define H_MISCB2_O               0xFFFFFFFF
#define H_MISCB3_O               0xFFFFFFFF
#define H_MISCB4_O               0xFFFFFFFF
#define H_MISCB5_O               0xFFFFFFFF
#define H_MISCB6_O               0xFFFFFFFF
#define H_MISCB7_O               0xFFFFFFFF
#define H_MISCB8_O               0xFFFFFFFF
#define H_MISC0_O                0xFFFFFFFF
#define H_MISC1_O                0xFFFFFFFF
#define H_MISC2_O                0xFFFFFFFF
#define H_MISC3_O                0xFFFFFFFF
#define H_MISC4_O                0xFFFFFFFF
#define H_MISC5_O                0xFFFFFFFF
#define H_MISC6_O                0xFFFFFFFF
#define H_MISC7_O                0xFFFFFFFF
#define H_MISC8_O                0xFFFFFFFF


/* Timer	*/
#define H_TIMER0_O              0xFFFFFFFF
#define H_TIMER1_O              0xFFFFFFFF
#define H_TIMER0_PBEN_O         0xFFFFFFFF
#define H_TIMER1_PBEN_O         0xFFFFFFFF

/* UART  */
#define H_UART0_TX_O            0xFFFFFFFF
#define H_UART0_TX_PBEN_O       0xFFFFFFFF


/*  TWI  */
#define H_TWI_DATA_PBEN_O       0xFFFFFFFF
#define H_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  H_SR_SDAT_O             0xffffffff


/* DAI SRU Group I dummy signals */

/* DAI Pin buffer  */

#define I_DAI_PB09_O            0xFFFFFFFF
#define I_DAI_PB10_O            0xFFFFFFFF
#define I_DAI_PB11_O            0xFFFFFFFF
#define I_DAI_PB12_O            0xFFFFFFFF
#define I_DAI_PB13_O            0xFFFFFFFF
#define I_DAI_PB14_O            0xFFFFFFFF
#define I_DAI_PB15_O            0xFFFFFFFF
#define I_DAI_PB16_O            0xFFFFFFFF
#define I_DAI_PB17_O            0xFFFFFFFF
#define I_DAI_PB18_O            0xFFFFFFFF
#define I_DAI_PB19_O            0xFFFFFFFF
#define I_DAI_PB20_O            0xFFFFFFFF

/* SPORT */

#define I_SPORT0_CLK_O          0xFFFFFFFF
#define I_SPORT1_CLK_O          0xFFFFFFFF
#define I_SPORT2_CLK_O          0xFFFFFFFF
#define I_SPORT3_CLK_O          0xFFFFFFFF
#define I_SPORT4_CLK_O          0xFFFFFFFF
#define I_SPORT5_CLK_O          0xFFFFFFFF
#define I_SPORT6_CLK_O          0xFFFFFFFF
#define I_SPORT7_CLK_O          0xFFFFFFFF

#define I_SPORT0_FS_O           0xFFFFFFFF
#define I_SPORT1_FS_O           0xFFFFFFFF
#define I_SPORT2_FS_O           0xFFFFFFFF
#define I_SPORT3_FS_O           0xFFFFFFFF
#define I_SPORT4_FS_O           0xFFFFFFFF
#define I_SPORT5_FS_O           0xFFFFFFFF
#define I_SPORT6_FS_O           0xFFFFFFFF
#define I_SPORT7_FS_O           0xFFFFFFFF


#define I_SPORT0_TDV_O          0xFFFFFFFF
#define I_SPORT1_TDV_O          0xFFFFFFFF
#define I_SPORT2_TDV_O          0xFFFFFFFF
#define I_SPORT3_TDV_O          0xFFFFFFFF
#define I_SPORT4_TDV_O          0xFFFFFFFF
#define I_SPORT5_TDV_O          0xFFFFFFFF
#define I_SPORT6_TDV_O          0xFFFFFFFF
#define I_SPORT7_TDV_O          0xFFFFFFFF

#define I_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT4_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT5_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT6_CLK_PBEN_O     0xFFFFFFFF
#define I_SPORT7_CLK_PBEN_O     0xFFFFFFFF

#define I_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT4_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT5_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT6_FS_PBEN_O      0xFFFFFFFF
#define I_SPORT7_FS_PBEN_O      0xFFFFFFFF

#define I_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT4_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT5_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT6_DA_PBEN_O      0xFFFFFFFF
#define I_SPORT7_DA_PBEN_O      0xFFFFFFFF

#define I_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT4_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT5_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT6_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT7_DB_PBEN_O      0xFFFFFFFF
#define I_SPORT7_DB_PBEN_O      0xFFFFFFFF

#define I_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT4_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT5_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT6_TDV_PBEN_O     0xFFFFFFFF
#define I_SPORT7_TDV_PBEN_O     0xFFFFFFFF

/*  ASRC	*/
#define I_SRC0_DAT_OP_O         0xFFFFFFFF
#define I_SRC1_DAT_OP_O         0xFFFFFFFF
#define I_SRC2_DAT_OP_O         0xFFFFFFFF
#define I_SRC3_DAT_OP_O         0xFFFFFFFF
#define I_SRC0_TDM_IP_O         0xFFFFFFFF
#define I_SRC1_TDM_IP_O         0xFFFFFFFF
#define I_SRC2_TDM_IP_O         0xFFFFFFFF
#define I_SRC3_TDM_IP_O         0xFFFFFFFF

/* PCG 	*/

#define	I_PCG_CLKA_O			0xFFFFFFFF
#define	I_PCG_CLKB_O			0xFFFFFFFF
#define I_PCG_CLKC_O            0xFFFFFFFF
#define I_PCG_CLKD_O            0xFFFFFFFF
#define I_PCG_FSA_O           	0xFFFFFFFF
#define I_PCG_FSB_O           	0xFFFFFFFF
#define I_PCG_FSC_O             0xFFFFFFFF
#define I_PCG_FSD_O             0xFFFFFFFF

/* 	S/PDIF  */
#define	I_DIR_CLK_O				0xFFFFFFFF
#define	I_DIR_TDMCLK_O			0xFFFFFFFF
#define I_DIR_FS_O           	0xFFFFFFFF
#define I_DIR_DAT_O		        0xFFFFFFFF
#define I_DIR_LRCLK_FB_O        0xFFFFFFFF
#define I_DIR_LRCLK_REF_O       0xFFFFFFFF
#define I_DIT_O			        0xFFFFFFFF
#define I_BLK_START_O           0xFFFFFFFF

/* MISCA	*/
#define I_MISCA0_O              0xFFFFFFFF
#define I_MISCA1_O              0xFFFFFFFF
#define I_MISCA2_O              0xFFFFFFFF
#define I_MISCA3_O              0xFFFFFFFF
#define I_MISCA4_O              0xFFFFFFFF
#define I_MISCA5_O              0xFFFFFFFF

/* PDAP	*/
#define I_PDAP_STRB_O           0xFFFFFFFF

/* ------- DPI signals --------  */
/* DPI Pin buffer  */
#define I_DPI_PB01_O            0xFFFFFFFF
#define I_DPI_PB02_O            0xFFFFFFFF
#define I_DPI_PB03_O            0xFFFFFFFF
#define I_DPI_PB04_O            0xFFFFFFFF
#define I_DPI_PB05_O            0xFFFFFFFF
#define I_DPI_PB06_O            0xFFFFFFFF
#define I_DPI_PB07_O            0xFFFFFFFF
#define I_DPI_PB08_O            0xFFFFFFFF
#define I_DPI_PB09_O            0xFFFFFFFF
#define I_DPI_PB10_O            0xFFFFFFFF
#define I_DPI_PB11_O            0xFFFFFFFF
#define I_DPI_PB12_O            0xFFFFFFFF
#define I_DPI_PB13_O            0xFFFFFFFF
#define I_DPI_PB14_O            0xFFFFFFFF

/*  SPI  */
#define I_SPI_MISO_O            0xFFFFFFFF
#define I_SPI_MOSI_O            0xFFFFFFFF
#define I_SPI_CLK_O             0xFFFFFFFF
#define I_SPI_FLG0_O            0xFFFFFFFF
#define I_SPI_FLG1_O            0xFFFFFFFF
#define I_SPI_FLG2_O            0xFFFFFFFF
#define I_SPI_FLG3_O            0xFFFFFFFF

#define I_SPIB_MISO_O           0xFFFFFFFF
#define I_SPIB_MOSI_O           0xFFFFFFFF
#define I_SPIB_CLK_O            0xFFFFFFFF
#define I_SPIB_FLG0_O           0xFFFFFFFF
#define I_SPIB_FLG1_O           0xFFFFFFFF
#define I_SPIB_FLG2_O           0xFFFFFFFF
#define I_SPIB_FLG3_O           0xFFFFFFFF

#define I_SPI_MISO_PBEN_O       0xFFFFFFFF
#define I_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define I_SPI_CLK_PBEN_O        0xFFFFFFFF
#define I_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define I_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define I_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define I_SPI_FLG3_PBEN_O       0xFFFFFFFF

#define I_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define I_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define I_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define I_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define I_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define I_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define I_SPIB_FLG3_PBEN_O      0xFFFFFFFF

/* FLAG	 */
#define I_FLAG4_O               0xFFFFFFFF
#define I_FLAG5_O               0xFFFFFFFF
#define I_FLAG6_O               0xFFFFFFFF
#define I_FLAG7_O               0xFFFFFFFF
#define I_FLAG8_O               0xFFFFFFFF
#define I_FLAG9_O               0xFFFFFFFF
#define I_FLAG10_O              0xFFFFFFFF
#define I_FLAG11_O              0xFFFFFFFF
#define I_FLAG12_O              0xFFFFFFFF
#define I_FLAG13_O              0xFFFFFFFF
#define I_FLAG14_O              0xFFFFFFFF
#define I_FLAG15_O              0xFFFFFFFF

#define I_FLAG4_PBEN_O         0xFFFFFFFF
#define I_FLAG5_PBEN_O         0xFFFFFFFF
#define I_FLAG6_PBEN_O         0xFFFFFFFF
#define I_FLAG7_PBEN_O         0xFFFFFFFF
#define I_FLAG8_PBEN_O         0xFFFFFFFF
#define I_FLAG9_PBEN_O         0xFFFFFFFF
#define I_FLAG10_PBEN_O         0xFFFFFFFF
#define I_FLAG11_PBEN_O         0xFFFFFFFF
#define I_FLAG12_PBEN_O         0xFFFFFFFF
#define I_FLAG13_PBEN_O         0xFFFFFFFF
#define I_FLAG14_PBEN_O         0xFFFFFFFF
#define I_FLAG15_PBEN_O         0xFFFFFFFF

#define I_PWM1_AL_O             0xFFFFFFFF
#define I_PWM1_AH_O             0xFFFFFFFF
#define I_PWM1_BL_O             0xFFFFFFFF
#define I_PWM1_BH_O             0xFFFFFFFF
#define I_PWM2_AL_O             0xFFFFFFFF
#define I_PWM2_AH_O             0xFFFFFFFF
#define I_PWM2_BL_O             0xFFFFFFFF
#define I_PWM2_BH_O             0xFFFFFFFF
#define I_PWM3_AL_O             0xFFFFFFFF
#define I_PWM3_AH_O             0xFFFFFFFF
#define I_PWM3_BL_O             0xFFFFFFFF
#define I_PWM3_BH_O             0xFFFFFFFF

#define I_PWM1_AL_PBEN_O             0xFFFFFFFF
#define I_PWM1_AH_PBEN_O             0xFFFFFFFF
#define I_PWM1_BL_PBEN_O             0xFFFFFFFF
#define I_PWM1_BH_PBEN_O             0xFFFFFFFF
#define I_PWM2_AL_PBEN_O             0xFFFFFFFF
#define I_PWM2_AH_PBEN_O             0xFFFFFFFF
#define I_PWM2_BL_PBEN_O             0xFFFFFFFF
#define I_PWM2_BH_PBEN_O             0xFFFFFFFF
#define I_PWM3_AL_PBEN_O             0xFFFFFFFF
#define I_PWM3_AH_PBEN_O             0xFFFFFFFF
#define I_PWM3_BL_PBEN_O             0xFFFFFFFF
#define I_PWM3_BH_PBEN_O             0xFFFFFFFF

/*  MISCB  */
#define I_MISCB0_O               0xFFFFFFFF
#define I_MISCB1_O               0xFFFFFFFF
#define I_MISCB2_O               0xFFFFFFFF
#define I_MISCB3_O               0xFFFFFFFF
#define I_MISCB4_O               0xFFFFFFFF
#define I_MISCB5_O               0xFFFFFFFF
#define I_MISCB6_O               0xFFFFFFFF
#define I_MISCB7_O               0xFFFFFFFF
#define I_MISCB8_O               0xFFFFFFFF
#define I_MISC0_O                0xFFFFFFFF
#define I_MISC1_O                0xFFFFFFFF
#define I_MISC2_O                0xFFFFFFFF
#define I_MISC3_O                0xFFFFFFFF
#define I_MISC4_O                0xFFFFFFFF
#define I_MISC5_O                0xFFFFFFFF
#define I_MISC6_O                0xFFFFFFFF
#define I_MISC7_O                0xFFFFFFFF
#define I_MISC8_O                0xFFFFFFFF


/* Timer	*/
#define I_TIMER0_O              0xFFFFFFFF
#define I_TIMER1_O              0xFFFFFFFF
#define I_TIMER0_PBEN_O         0xFFFFFFFF
#define I_TIMER1_PBEN_O         0xFFFFFFFF


/* UART  */
#define I_UART0_TX_O            0xFFFFFFFF
#define I_UART0_TX_PBEN_O       0xFFFFFFFF

/*  TWI  */
#define I_TWI_DATA_PBEN_O       0xFFFFFFFF
#define I_TWI_CLK_PBEN_O        0xFFFFFFFF

/* Shift Register */

#define  I_SR_LAT_O              0xffffffff
#define  I_SR_SCLK_O             0xffffffff








#ifdef _MISRA_RULES
#pragma diag(pop)
#endif /* _MISRA_RULES */

#endif /* __SRU21479_H_ */
